@@ -11,7 +11,7 @@
  *
  *  divx4/divx5 unification by Alex Stewart <alex@foogod.com>
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -106,30 +106,36 @@ static int divx_init(char *path) {
 #endif  
   char *error;
   int *quiet_encore;
+
+	fprintf(stderr, "[%s] *** Warning: DivX is broken and support for it is ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** obsolete in transcode. Sooner or later it  ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** will be removed from transcode. Don't use ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** DivX. Use xvid or ffmpeg -F mpeg4 instead ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** for all your mpeg4 encodings. ***\n", MOD_NAME);
   
   handle = NULL;
 
   // try transcode's module directory
   if (!handle) {
     // (try 5.x "libdivxencore.so.0" style)
-    sprintf(module, "%s/%s", path, MODULE_V);
+    snprintf(module, sizeof(module), "%s/%s", path, MODULE_V);
     handle = dlopen(module, RTLD_LAZY); 
   }
   if (!handle) {
     // (try 4.x "libdivxencore.so" style)
-    sprintf(module, "%s/%s", path, MODULE);
+    snprintf(module, sizeof(module), "%s/%s", path, MODULE);
     handle = dlopen(module, RTLD_LAZY); 
   }
 
   //try the default:
   if (!handle) {
     // (try 5.x "libdivxencore.so.0" style)
-    sprintf(module, "%s", MODULE_V);
+    snprintf(module, sizeof(module), "%s", MODULE_V);
     handle = dlopen(module, RTLD_LAZY); 
   }
   if (!handle) {
     // (try 4.x "libdivxencore.so" style)
-    sprintf(module, "%s", MODULE);
+    snprintf(module, sizeof(module), "%s", MODULE);
     handle = dlopen(module, RTLD_LAZY); 
   }
     
