@@ -9,7 +9,7 @@
  *  constant quantizer extensions "-R 3" by Gerhard Monzel 
  *  <gerhard.monzel@sap.com>
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@
 #include "avilib.h"
 #include "aud_aux.h"
 #include "vbr.h"
+#include "ioaux.h"
 
 #define MOD_NAME    "export_divx4raw.so"
 #define MOD_VERSION "v0.3.6 (2003-07-24)"
@@ -85,6 +86,7 @@ static char module[TC_BUF_MAX];
 
 #define MODULE "libdivxencore.so"
 
+#if 0  /* get this from ioaux.c */
 static int p_write (int fd, char *buf, size_t len)
 {
    size_t n = 0;
@@ -99,6 +101,7 @@ static int p_write (int fd, char *buf, size_t len)
    }
    return r;
 }
+#endif
 
 
 static int divx4_init(char *path) {
@@ -107,8 +110,14 @@ static int divx4_init(char *path) {
 #endif  
   char *error;
   int *quiet_encore;
+
+	fprintf(stderr, "[%s] *** Warning: DivX is broken and support for it is ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** obsolete in transcode. Sooner or later it  ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** will be removed from transcode. Don't use ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** DivX. Use xvid or ffmpeg -F mpeg4 instead ***\n", MOD_NAME);
+	fprintf(stderr, "[%s] *** for all your mpeg4 encodings. ***\n", MOD_NAME);
   
-  sprintf(module, "%s/%s", path, MODULE);
+  snprintf(module, sizeof(module), "%s/%s", path, MODULE);
   
   // try transcode's module directory
   
