@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Yannick Vignon - February 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ int read_stats(fame_frame_statistics_t *stats)
 	 &stats->target_bits,
 	 &stats->actual_bits,
 	 &stats->spatial_activity,
-	 &stats->quant_scale);
+	 (int*)&stats->quant_scale);
 
   return 0;
 }
@@ -82,7 +82,7 @@ void print_stats(fame_frame_statistics_t *stats)
 	 stats->target_bits,
 	 stats->actual_bits,
 	 stats->spatial_activity,
-	 stats->quant_scale);
+	 (int)stats->quant_scale);
 }
 
 
