@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <netdb.h>
 
 #include "transcode.h"
+#include "ioaux.h"
 
 #define MOD_NAME    "export_net.so"
 #define MOD_VERSION "v0.0.2 (2003-01-09)"
@@ -47,6 +48,7 @@ static pthread_t thread1, thread2;
 
 static int size;
 
+#if 0  /* get this from ioaux.c */
 static size_t p_write (int fd, char *buf, size_t len)
 {
    size_t n = 0;
@@ -61,6 +63,7 @@ static size_t p_write (int fd, char *buf, size_t len)
    }
    return r;
 }
+#endif
 
 void vlisten() 
 {
