@@ -6,7 +6,7 @@
  *  Original Author    : Christoph Lampert <gruel@web.de> 
  *  Current maintainer : Edouard Gomez <ed.gomez@free.fr>
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software ; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -64,6 +64,7 @@
 #include "transcode.h"
 #include "avilib.h"
 #include "aud_aux.h"
+#include "ioaux.h"
 
 #ifdef DEVELOPER_USE
 #include "libioaux/configs.h"
@@ -163,7 +164,9 @@ static int xvid_print_config(XVID_INIT_PARAM *einit,
 
 static void xvid_print_vbr(vbr_control_t *state);
 
+#if 0  /* get this from ioaux.h */
 static int p_write(int fd, char *buf, size_t len);
+#endif
 
 /*****************************************************************************
  * Init codec
@@ -607,22 +610,22 @@ static int xvid2_init(char *path)
 
 	/* First we build all lib names we will try to load */
 #ifdef SYSTEM_DARWIN
-	sprintf(modules[0], "%s/%s.%d.%s", path, XVID_SHARED_LIB_BASE,
+	snprintf(modules[0], sizeof(modules[0]), "%s/%s.%d.%s", path, XVID_SHARED_LIB_BASE,
 		API_VERSION>>16, XVID_SHARED_LIB_SUFX);
 #else
-	sprintf(modules[0], "%s/%s.%s.%d", path, XVID_SHARED_LIB_BASE,
+	snprintf(modules[0], sizeof(modules[0]), "%s/%s.%s.%d", path, XVID_SHARED_LIB_BASE,
 		XVID_SHARED_LIB_SUFX, API_VERSION>>16);
 #endif
 #ifdef SYSTEM_DARWIN
-	sprintf(modules[1], "%s.%d.%s", XVID_SHARED_LIB_BASE,
+	snprintf(modules[1], sizeof(modules[1]), "%s.%d.%s", XVID_SHARED_LIB_BASE,
 		API_VERSION>>16, XVID_SHARED_LIB_SUFX);
 #else
-	sprintf(modules[1], "%s.%s.%d", XVID_SHARED_LIB_BASE,
+	snprintf(modules[1], sizeof(modules[1]), "%s.%s.%d", XVID_SHARED_LIB_BASE,
 		XVID_SHARED_LIB_SUFX, API_VERSION>>16);
 #endif
-	sprintf(modules[2], "%s/%s.%s", path, XVID_SHARED_LIB_BASE,
+	snprintf(modules[2], sizeof(modules[2]), "%s/%s.%s", path, XVID_SHARED_LIB_BASE,
 		XVID_SHARED_LIB_SUFX);
-	sprintf(modules[3], "%s.%s", XVID_SHARED_LIB_BASE,
+	snprintf(modules[3], sizeof(modules[3]), "%s.%s", XVID_SHARED_LIB_BASE,
 		XVID_SHARED_LIB_SUFX);
 
 	for(i=0; i<4; i++) {
@@ -1705,6 +1708,7 @@ static void xvid_print_vbr(vbr_control_t *state)
 		state->fixed_quant);
 }
 
+#if 0  /* get this from ioaux.c */
 static int p_write(int fd, char *buf, size_t len)
 {
    size_t n = 0;
@@ -1719,6 +1723,7 @@ static int p_write(int fd, char *buf, size_t len)
    }
    return r;
 }
+#endif
 
 /*
  * Please do not modify the tag line.
