@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - January 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
 #ifndef _VID_AUX_H
 #define _VID_AUX_H
 
-#include "config.h"
 #include "transcode.h"
+
 #include "libvo/rgb2yuv.h"
 #include "libvo/yuv2rgb.h"
 
