@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,28 +24,14 @@
 #define MOD_NAME    "filter_32drop.so"
 #define MOD_VERSION "v0.4 (2003-02-01)"
 #define MOD_CAP     "3:2 inverse telecine removal plugin"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
+#define MOD_AUTHOR  "Chad Page"
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
+#include <inttypes.h>
+
 // basic parameter
 static int color_diff_threshold1=50;
 static int color_diff_threshold2=100;
