@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,28 +24,14 @@
 #define MOD_NAME    "filter_aclip.so"
 #define MOD_VERSION "v0.1.1 (2003-09-04)"
 #define MOD_CAP     "generate audio clips from source"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <math.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#define MOD_AUTHOR  "Thomas Oestreich"
 
 #include "transcode.h"
-#include "framebuffer.h"
-
+#include "filter.h"
 #include "optstr.h"
 
+#include <math.h>
+
 static uint64_t total=0;
 
 static int level=10, range=25, range_ctr=0, skip_mode=0;
@@ -73,24 +59,6 @@ int tc_filter(aframe_list_t *ptr, char *options)
 
   vob_t *vob=NULL;
 
-  // API explanation:
-  // ================
-  //
-  // (1) need more infos, than get pointer to transcode global 
-  //     information structure vob_t as defined in transcode.h.
-  //
-  // (2) 'tc_get_vob' and 'verbose' are exported by transcode.
-  //
-  // (3) filter is called first time with TC_FILTER_INIT flag set.
-  //
-  // (4) make sure to exit immediately if context (video/audio) or 
-  //     placement of call (pre/post) is not compatible with the filters 
-  //     intended purpose, since the filter is called 4 times per frame.
-  //
-  // (5) see framebuffer.h for a complete list of frame_list_t variables.
-  //
-  // (6) filter is last time with TC_FILTER_CLOSE flag set
-
   if(ptr->tag & TC_FILTER_GET_CONFIG) {
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, "Thomas Oestreich", "AE", "1");
       optstr_param (options, "level", "The audio must be under this level to be skipped", "%d", "10", "0", "255");
@@ -98,15 +66,12 @@ int tc_filter(aframe_list_t *ptr, char *options)
       return 0;
   }
 
-
   //----------------------------------
   //
   // filter init
   //
   //----------------------------------
 
-  
-
   if(ptr->tag & TC_FILTER_INIT) {
     
     if((vob = tc_get_vob())==NULL) return(-1);
@@ -137,7 +102,6 @@ int tc_filter(aframe_list_t *ptr, char *options)
   //
   //----------------------------------
 
-  
   if(ptr->tag & TC_FILTER_CLOSE) {
     
     return(0);
