@@ -4,7 +4,7 @@
  *  Copyright (C) Antonio Beamud Montero <antonio.beamud@linkend.com>
  *  Copyright (C) Microgenesis S.A.
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,33 +27,17 @@
 #define MOD_CAP     "compare with other image to find a pattern"
 #define MOD_AUTHOR  "Antonio Beamud"
 
-#define DELTA_COLOR 45.0
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <math.h>
-
-// FIXME: Try to implement the YUV colorspace
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <inttypes.h>
-
-
 #include "transcode.h"
-#include "framebuffer.h"
 #include "filter.h"
 #include "optstr.h"
 
+#include <math.h>
+#include <inttypes.h>
+
+#define DELTA_COLOR 45.0
+
+// FIXME: Try to implement the YUV colorspace
+
 // transcode defines this as well as ImageMagick.
 #undef PACKAGE_NAME
 #undef PACKAGE_TARNAME
@@ -190,7 +174,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 			
 			if (strlen(results_name) == 0) {
 				// Ponemos el nombre del fichero al original con extension dat
-				strcpy(results_name,"/tmp/compare.dat");
+				strlcpy(results_name, "/tmp/compare.dat", sizeof(results_name));
 				
 			}
 			if (!(compare[instance]->results = fopen(results_name, "w")))
@@ -203,7 +187,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				
 			GetExceptionInfo(&exception_info);
 			image_info = CloneImageInfo ((ImageInfo *) NULL);
-			strcpy(image_info->filename,pattern_name);
+			strlcpy(image_info->filename, pattern_name, MaxTextExtent);
 			if (verbose > 1)
 			     printf("Trying to open image\n");
 			orig = ReadImage(image_info,
@@ -213,7 +197,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 				MagickWarning(exception_info.severity,
 					      exception_info.reason,
 					      exception_info.description);
-				strcpy(pattern_name, "/dev/null");
+				strlcpy(pattern_name, "/dev/null", sizeof(pattern_name));
 			}else{
 			       if (verbose > 1)
 			       		printf("[%s] Image loaded successfully\n", MOD_NAME);
