@@ -12,7 +12,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *     
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,26 +33,13 @@
 #define MOD_NAME    "filter_cpaudio.so"
 #define MOD_VERSION "v0.1 (2003-04-30)"
 #define MOD_CAP     "copy one audio channel to the other channel filter plugin"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#define MOD_AUTHOR  "William H Wittig"
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
+
 /*-------------------------------------------------
  * local utility functions
  *-------------------------------------------------*/
@@ -75,24 +62,6 @@ int tc_filter(aframe_list_t *ptr, char *options)
   vob_t *vob=NULL;
   static int sourceChannel = 0;    // Init to left. '1' = right
    
-  // API explanation:
-  // ================
-  //
-  // (1) need more info, then get pointer to transcode global
-  //     information structure vob_t as defined in transcode.h.
-  //
-  // (2) 'tc_get_vob' and 'verbose' are exported by transcode.
-  //
-  // (3) filter is called first time with TC_FILTER_INIT flag set.
-  //
-  // (4) make sure to exit immediately if context (video/audio) or
-  //     placement of call (pre/post) is not compatible with the filters
-  //     intended purpose, since the filter is called 4 times per frame.
-  //
-  // (5) see framebuffer.h for a complete list of frame_list_t variables.
-  //
-  // (6) filter is called last time with TC_FILTER_CLOSE flag set
-
   if (ptr->tag & TC_FILTER_GET_CONFIG) {
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, "William H Wittig", "AO", "1");
       optstr_param (options, "source", "Source channel (l=left, r=right)", "%c", "l", "l", "r");
@@ -143,7 +112,6 @@ int tc_filter(aframe_list_t *ptr, char *options)
   //----------------------------------
   // filter close
   //----------------------------------
-
  
   if(ptr->tag & TC_FILTER_CLOSE)
   {
