@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich, Chad Page - February/March 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,27 +26,14 @@
 #define MOD_CAP     "chroma-lag shifter"
 #define MOD_AUTHOR  "Thomas streich, Chad Page"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include "transcode.h"
+#include "filter.h"
+#include "optstr.h"
 
 static char *buffer;
 
 static int loop=1;
 
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include "transcode.h"
-#include "framebuffer.h"
-#include "optstr.h"
-
 void crshift_yuv(char * buffer, vob_t *vob, int shift)
 {
 	int x, y;
@@ -140,25 +127,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
   static vob_t *vob=NULL;
 
-  // API explanation:
-  // ================
-  //
-  // (1) need more infos, than get pointer to transcode global 
-  //     information structure vob_t as defined in transcode.h.
-  //
-  // (2) 'tc_get_vob' and 'verbose' are exported by transcode.
-  //
-  // (3) filter is called first time with TC_FILTER_INIT flag set.
-  //
-  // (4) make sure to exit immediately if context (video/audio) or 
-  //     placement of call (pre/post) is not compatible with the filters 
-  //     intended purpose, since the filter is called 4 times per frame.
-  //
-  // (5) see framebuffer.h for a complete list of frame_list_t variables.
-  //
-  // (6) filter is last time with TC_FILTER_CLOSE flag set
-
-
   if(ptr->tag & TC_FILTER_GET_CONFIG) {
       char buf[32];
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VRYE", "1");
@@ -167,13 +135,13 @@ int tc_filter(vframe_list_t *ptr, char *options)
       optstr_param (options, "shift", "Shift chroma(color) to the left", "%d", buf, "0", "width");
       return 0;
   }
+
   //----------------------------------
   //
   // filter init
   //
   //----------------------------------
 
-
   if(ptr->tag & TC_FILTER_INIT) {
     
     if((vob = tc_get_vob())==NULL) return(-1);
@@ -203,7 +171,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // filter close
   //
   //----------------------------------
-
   
   if(ptr->tag & TC_FILTER_CLOSE) {
     
@@ -219,20 +186,19 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // filter frame routine
   //
   //----------------------------------
-  
-  
+    
   // tag variable indicates, if we are called before
   // transcodes internal video/audo frame processing routines
   // or after and determines video/audio context
   
   if(ptr->tag & TC_PRE_M_PROCESS && ptr->tag & TC_VIDEO && !(ptr->attributes & TC_FRAME_IS_SKIPPED)) {
 
-      memcpy(buffer, ptr->video_buf, ptr->v_width*ptr->v_height*3);
+      tc_memcpy(buffer, ptr->video_buf, ptr->v_width*ptr->v_height*3);
 
       if (vob->im_v_codec == CODEC_YUV) crshift_yuv(buffer, vob, loop);
       if (vob->im_v_codec == CODEC_RGB) crshift_rgb(buffer, vob, loop);
       
-      memcpy(ptr->video_buf, buffer, ptr->v_width*ptr->v_height*3);
+      tc_memcpy(ptr->video_buf, buffer, ptr->v_width*ptr->v_height*3);
   } 
   
   return(0);
