@@ -22,7 +22,13 @@
 #define MOD_NAME    "filter_denoise3d.so"
 #define MOD_VERSION "v1.0.6 (2003-12-20)"
 #define MOD_CAP     "High speed 3D Denoiser"
-#define MOD_AUTHOR  "Daniel Moreno & A'rpi"
+#define MOD_AUTHOR  "Daniel Moreno, A'rpi"
+
+#include "transcode.h"
+#include "filter.h"
+#include "optstr.h"
+
+#include <math.h>
 
 #define module "[" MOD_NAME "]: "
 
@@ -40,21 +46,6 @@
 	1.0.6	EMS	fixed annoying typo
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <inttypes.h>
-#include <math.h>
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include "transcode.h"
-#include "framebuffer.h"
-#include "filter.h"
-#include "optstr.h"
-
 #define MAX_PLANES 3
 
 #define DEFAULT_LUMA_SPATIAL 4.0
