@@ -3,7 +3,7 @@
  *
  *  (c) by Matthias Hopf - August 2004
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,27 +30,21 @@
 #define MOD_NAME    "filter_fieldanalysis.so"
 #define MOD_VERSION "v1.0 pl1 (2004-08-13)"
 #define MOD_CAP     "Field analysis for detecting interlace and telecine"
-#define MOD_AUTHORS "Matthias Hopf"
+#define MOD_AUTHOR  "Matthias Hopf"
 
+#include "transcode.h"
+#include "filter.h"
+#include "optstr.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
+#if 0
+#include "aclib/ac.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
 #include <assert.h>
 
-#include "transcode.h"
-#include "framebuffer.h"
-#include "optstr.h"
-#if 0
-#include "aclib/ac.h"
-#endif
-
 
 /*
  * State
@@ -498,7 +492,7 @@ int tc_filter (vframe_list_t *ptr, char *options)
 			"  'fieldanalysis' scans video for interlacing artifacts and\n"
 			"  detects progressive / interlaced / telecined video.\n"
 			"  It also determines the major field for interlaced video.\n"
-			"* Verbose Output:   [PtPb c t eteb]\n"
+			"* Verbose Output:   [PtPb c t stsb]\n"
 			"  Pt, Pb:   progressivediff succeeded, per field.\n"
 			"  pt, pb:   unknowndiff succeeded, progressivediff failed.\n"
 			"  c:        progressivechange succeeded.\n"
@@ -603,22 +597,22 @@ int tc_filter (vframe_list_t *ptr, char *options)
     if (ptr->tag & TC_FILTER_GET_CONFIG) {
 	char buf[255];
 	optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION,
-			    MOD_AUTHORS, "VRY4E", "2");
-	sprintf (buf, "%g", myf->interlaceDiff);
+			    MOD_AUTHOR, "VRY4E", "2");
+	snprintf (buf, sizeof(buf), "%g", myf->interlaceDiff);
 	optstr_param (options, "interlacediff", "Minimum temporal inter-field difference for detecting interlaced video", "%f", buf, "1.0", "inf");
-	sprintf (buf, "%g", myf->unknownDiff);
+	snprintf (buf, sizeof(buf), "%g", myf->unknownDiff);
 	optstr_param (options, "unknowndiff", "Maximum inter-frame change vs. detail differences for neglecting interlaced video", "%f", buf, "1.0", "inf");
-	sprintf (buf, "%g", myf->progressiveDiff);
+	snprintf (buf, sizeof(buf), "%g", myf->progressiveDiff);
 	optstr_param (options, "progressivediff", "Minimum inter-frame change vs. detail differences for detecting progressive video" ,"%f", buf, "unknowndiff", "inf");
-	sprintf (buf, "%g", myf->progressiveChange);
+	snprintf (buf, sizeof(buf), "%g", myf->progressiveChange);
 	optstr_param (options, "progressivechange", "Minimum temporal change needed for detecting progressive video" ,"%f", buf, "0", "inf");
-	sprintf (buf, "%g", myf->changedIfMore);
+	snprintf (buf, sizeof(buf), "%g", myf->changedIfMore);
 	optstr_param (options, "changedifmore", "Minimum temporal change for detecting truly changed frames" ,"%f", buf, "0", "65025");
-	sprintf (buf, "%d", myf->forceTelecineDetect);
+	snprintf (buf, sizeof(buf), "%d", myf->forceTelecineDetect);
 	optstr_param (options, "forcetelecinedetect", "Detect telecine even on non-NTSC (29.97fps) video", "%d", buf, "0", "1");
-	sprintf (buf, "%d", myf->verbose);
+	snprintf (buf, sizeof(buf), "%d", myf->verbose);
 	optstr_param (options, "verbose", "Output analysis for every frame", "%d", buf, "0", "2");
-	sprintf (buf, "%d", myf->outDiff);
+	snprintf (buf, sizeof(buf), "%d", myf->outDiff);
 	optstr_param (options, "outdiff", "Output internal debug frames as luminance of YUV video (see source)", "%d", buf, "0", "11");
     }
     
