@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Tilmann Bitterberg - April 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,31 +32,13 @@
 #define MOD_CAP     "render image in videostream"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "transcode.h"
+#include "filter.h"
 #include "optstr.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-
-
-#include <unistd.h>
-#include <inttypes.h>
-
-#include "framebuffer.h"
-#include "filter.h"
 #include "export/vid_aux.h"
 
+
 // transcode defines this as well as ImageMagick.
 #undef PACKAGE_NAME
 #undef PACKAGE_TARNAME
@@ -170,7 +152,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
     if((mfd = (MyFilterData *)malloc (sizeof(MyFilterData))) == NULL) return (-1);
 
     //mfd->file = filename;
-    strcpy (mfd->file, "logo.png");
+    strlcpy (mfd->file, "logo.png", PATH_MAX);
     mfd->yuv   = NULL;
     mfd->flip  = 0;
     mfd->pos   = 0;
@@ -218,12 +200,12 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
     GetExceptionInfo (&exception_info);
     image_info = CloneImageInfo ((ImageInfo *) NULL);
-    strcpy(image_info->filename, mfd->file);
+    strlcpy(image_info->filename, mfd->file, MaxTextExtent);
 
     image = ReadImage (image_info, &exception_info);
     if (image == (Image *) NULL) {
         MagickWarning (exception_info.severity, exception_info.reason, exception_info.description);
-	strcpy(mfd->file, "/dev/null");
+	strlcpy(mfd->file, "/dev/null", PATH_MAX);
 	return 0;
     }
 
