@@ -6,7 +6,7 @@
  *  This plugin is based on ideas of Krzysztof Wojdon's
  *  logoaway filter for VirtualDub
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -66,27 +66,12 @@
 #define MOD_NAME    "filter_logoaway.so"
 #define MOD_VERSION "v0.5 (2004-03-07)"
 #define MOD_CAP     "remove an image from the video"
-#define MOD_AUTHOR  "Thomas Wehrspann <thomas@wehrspann.de>"
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
+#define MOD_AUTHOR  "Thomas Wehrspann"
 
 #include "transcode.h"
-#include "framebuffer.h"
 #include "filter.h"
 #include "optstr.h"
+
 #include "tc_func_excl.h"
 
 // transcode defines this as well as ImageMagick.
@@ -211,7 +196,7 @@ void work_with_rgb_frame(char *buffer, int width, int height, int instance)
     }
 
     data[instance]->dumpimage = ConstituteImage(data[instance]->width-data[instance]->xpos, data[instance]->height-data[instance]->ypos, "RGB", CharPixel, data[instance]->dump_buf, &data[instance]->exception_info);
-    sprintf (data[instance]->dumpimage->filename, "dump[%d].png", instance);
+    snprintf (data[instance]->dumpimage->filename, MaxTextExtent, "dump[%d].png", instance);
 
     WriteImage(data[instance]->dumpimage_info, data[instance]->dumpimage);
   }
@@ -609,31 +594,31 @@ int tc_filter(vframe_list_t *ptr, char *options)
     char buf[255];
     optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VRYOM", "1");
 
-    sprintf (buf, "%u-%u", data[instance]->start, data[instance]->end);
+    snprintf (buf, sizeof(buf), "%u-%u", data[instance]->start, data[instance]->end);
     optstr_param (options, "range",  "Frame Range",                         "%d-%d",     buf, "0", "oo",    "0", "oo");
 
-    sprintf (buf, "%dx%d", data[instance]->xpos, data[instance]->ypos);
+    snprintf (buf, sizeof(buf), "%dx%d", data[instance]->xpos, data[instance]->ypos);
     optstr_param (options, "pos",    "Position of logo",                    "%dx%d",     buf, "0", "width", "0", "height");
 
-    sprintf (buf, "%dx%d", data[instance]->width, data[instance]->height);
+    snprintf (buf, sizeof(buf), "%dx%d", data[instance]->width, data[instance]->height);
     optstr_param (options, "size",   "Size of logo",                        "%dx%d",     buf, "0", "width", "0", "height");
 
-    sprintf (buf, "%d", data[instance]->mode);
+    snprintf (buf, sizeof(buf), "%d", data[instance]->mode);
     optstr_param (options, "mode",   "Filter Mode (0=none,1=solid,2=xy,3=shape)", "%d",  buf, "0", "3");
 
-    sprintf (buf, "%d",  data[instance]->border);
+    snprintf (buf, sizeof(buf), "%d",  data[instance]->border);
     optstr_param (options, "border", "Visible Border",                      "",          buf);
 
-    sprintf (buf, "%d",  data[instance]->dump);
+    snprintf (buf, sizeof(buf), "%d",  data[instance]->dump);
     optstr_param (options, "dump", "Dump filterarea to file",               "",          buf);
     
-    sprintf (buf, "%d", data[instance]->xweight);
+    snprintf (buf, sizeof(buf), "%d", data[instance]->xweight);
     optstr_param (options, "xweight","X-Y Weight(0%-100%)",                 "%d",        buf, "0", "100");
 
-    sprintf (buf, "%x%x%x", data[instance]->rcolor, data[instance]->gcolor, data[instance]->bcolor);
+    snprintf (buf, sizeof(buf), "%x%x%x", data[instance]->rcolor, data[instance]->gcolor, data[instance]->bcolor);
     optstr_param (options, "fill",   "Solid Fill Color(RGB)",               "%2x%2x%2x", buf, "00", "FF",   "00", "FF", "00", "FF");
 
-    sprintf (buf, "%s",  data[instance]->file);
+    snprintf (buf, sizeof(buf), "%s",  data[instance]->file);
     optstr_param (options, "file",   "Image with alpha/shape information",  "%s",        buf);
 
     return 0;
@@ -744,7 +729,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
       if(data[instance]->alpha) {
         data[instance]->image_info = CloneImageInfo((ImageInfo *) NULL);
   
-        strcpy(data[instance]->image_info->filename, data[instance]->file);
+        strlcpy(data[instance]->image_info->filename, data[instance]->file, MaxTextExtent);
         data[instance]->image = ReadImage(data[instance]->image_info, &data[instance]->exception_info);
         if (data[instance]->image == (Image *) NULL) {
           fprintf(stderr, "[%s] ERROR: ", MOD_NAME);
