@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Marrq - July 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *  Based on the excellent work of Donald Graft in Decomb and of
  *  Thanassis Tsiodras of transcode's decimate filter and Tilmann Bitterberg
  *      
@@ -52,31 +52,18 @@
 #define MOD_VERSION "v0.10 (2003-08-18)"
 #define MOD_CAP     "plugin to modify framerate"
 #define MOD_AUTHOR  "Marrq"
-//#define DEBUG 1
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <inttypes.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
-#include <math.h>
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
+#include <math.h>
+
+//#define DEBUG 1
+
+// FIXME
+extern long int lrint(double x);
+
 static int show_results=0;
 
 /*-------------------------------------------------
@@ -120,7 +107,7 @@ static void help_optstr()
     printf ("  For most users, modfps will need either no options, or just mode=1\n");
     printf ("* Options\n");
     printf ("\tmode : (0=unbuffered, 1=buffered [%d]\n", mode);
-    printf ("\tinfps : original fps (override what transcode supplies) [%lf]\n",infps);
+    printf ("\tinfps : original fps (override what transcode supplies) [%f]\n",infps);
     printf ("\tinfrc : original frc (overwrite infps) [%d]\n",infrc);
     printf ("\tbuffer : number of frames to buffer [%d]\n",numSample);
     printf ("\tsubsample : number of pixels to subsample when examining buffers [%d]\n",offset);
@@ -212,9 +199,15 @@ static void clone_phosphor_average(unsigned char *clone, unsigned char *next, vf
     //ptr->video_buf[i] = (unsigned char)lrint(pow( ( pow((double)clone[i], 3.0) +
     //					      pow((double)next[i],  3.0) ) / 2.0,
     //					      1.0/3.0));
+#ifdef HAVE_LIBM_LRINT
     ptr->video_buf[i] = (unsigned char)lrint(pow((double) (( clone[i]*clone[i]*clone[i] +
     					      next[i]*next[i]*next[i]) >> 1),
 					      1.0/3.0));
+#else
+    ptr->video_buf[i] = (unsigned char)(long)rint(pow((double) (( clone[i]*clone[i]*clone[i] +
+    					      next[i]*next[i]*next[i]) >> 1),
+					      1.0/3.0));
+#endif
   }
   for(; i<ptr->video_size; i++){
     ptr->video_buf[i] = (unsigned char)( ((short int)clone[i] + (short int)next[i]) >> 1);
@@ -262,7 +255,7 @@ static void clone_temporal_average(unsigned char *clone, unsigned char*next, vfr
     if (show_results){
       printf("[%s] temporal_clone: w1 is weak, copying next frame\n",MOD_NAME);
     }
-    memcpy(ptr->video_buf,next,ptr->video_size);
+    tc_memcpy(ptr->video_buf,next,ptr->video_size);
     return;
   } // else
   if (weight2 < 0.0){
@@ -291,7 +284,7 @@ static void clone_temporal_average(unsigned char *clone, unsigned char*next, vfr
 }
 
 static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
-  int i,width,height;
+  int i,width = 0,height;
   char *dest, *s1, *s2;
 
   if (CODEC_RGB == ptr->v_codec){
@@ -309,11 +302,11 @@ static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
   s1 = clone;
   s2 = next+width;
   for(i=0;i<height;i++){
-    memcpy(dest,s1,width);
+    tc_memcpy(dest,s1,width);
     dest += width;
     // check to make sure we don't have an odd number of rows;
     if (++i < height){
-      memcpy(dest,s2,width);
+      tc_memcpy(dest,s2,width);
       dest += width;
       s1 += width<<1;
       s2 += width<<1;
@@ -330,11 +323,11 @@ static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
     // we don't have to divide the height by 2 because we've
     // got two colors, we'll handle them in one sweep.
     for(i=0;i<height;i++){
-      memcpy(dest,s1,width);
+      tc_memcpy(dest,s1,width);
       dest+=width;
       // check to make sure we don't have an odd number of rows;
       if(++i < height){
-        memcpy(dest,s2,width);
+        tc_memcpy(dest,s2,width);
 	dest += width;
 	s1 += width<<1;
 	s2 += width<<1;
@@ -356,7 +349,7 @@ static void fancy_clone(char* clone, char* next, vframe_list_t *ptr, int tin, in
   //printf("[%s] fancy_clone clonetype: %d tin=%4d tout=%4d\n",MOD_NAME,clonetype,tin,tout);
   switch (clonetype){
     case 0:
-      memcpy(ptr->video_buf,clone,ptr->video_size);
+      tc_memcpy(ptr->video_buf,clone,ptr->video_size);
       break;
     case 1:
       clone_interpolate(clone,next,ptr);
@@ -465,7 +458,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  }
 	  optstr_get (options, "verbose", "%d", &show_results);
 	  optstr_get (options, "mode", "%d", &mode);
-	  optstr_get (options, "infps", "%lf", &infps);
+	  optstr_get (options, "infps", "%f", &infps);
 	  optstr_get (options, "infrc", "%d", &infrc);
 	  optstr_get (options, "buffer", "%d", &numSample);
 	  optstr_get (options, "subsample", "%d", &offset);
@@ -512,19 +505,19 @@ int tc_filter(vframe_list_t * ptr, char *options)
       char buf[255];
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYRE", "1");
 
-      sprintf(buf, "%d",mode);
+      snprintf(buf, sizeof(buf), "%d",mode);
       optstr_param(options,"mode","mode of operation", "%d", buf, "0", "1");
-      snprintf(buf, 128, "%lf", infps);
+      snprintf(buf, sizeof(buf), "%f", infps);
       optstr_param(options, "infps", "Original fps", "%f", buf, "MIN_FPS", "200.0");
-      snprintf(buf, 128, "%d", infrc);
+      snprintf(buf, sizeof(buf), "%d", infrc);
       optstr_param(options, "infrc", "Original frc", "%d", buf, "0", "16");
-      sprintf(buf, "%d", numSample);
+      snprintf(buf, sizeof(buf), "%d", numSample);
       optstr_param(options,"examine", "How many frames to buffer", "%d", buf, "2", "25");
-      sprintf(buf, "%d", offset);
+      snprintf(buf, sizeof(buf), "%d", offset);
       optstr_param(options, "subsample", "How many pixels to subsample", "%d", buf, "1", "256");
-      sprintf(buf, "%d", clonetype);
+      snprintf(buf, sizeof(buf), "%d", clonetype);
       optstr_param(options, "clonetype", "How to clone frames", "%d", buf, "0", "16");
-      sprintf(buf, "%d", verbose);
+      snprintf(buf, sizeof(buf), "%d", verbose);
       optstr_param(options, "verbose", "run in verbose mode", "%d", buf, "0", "1");
       return 0;
     }
@@ -617,7 +610,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  fancy_clone(frames[frameIn],frames[(frameIn+1)%frbufsize],ptr,framesin-numSample,outframes+cloneq+1);
 	  return 0;
 	} // else 
-	memcpy(frames[frameIn], ptr->video_buf, ptr->video_size);
+	tc_memcpy(frames[frameIn], ptr->video_buf, ptr->video_size);
 	framesOK[frameIn] = 1;
 #ifdef DEBUG
 	printf("Inserted frame %d into slot %d \n",framesin, frameIn);
@@ -692,7 +685,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    ++cloneq;
 	    framesOK[mod] = 0;
 	  }
-	  memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
+	  tc_memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
 	  if (framesOK[frameOut]){
 	    if (show_results){
 	      printf("giving   slot %2d frame %6d\n",frameOut,ptr->id);
@@ -732,7 +725,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	    ++outframes;
 	  }
 	  if (framesOK[frameOut]){
-	    memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
+	    tc_memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
 	    if (show_results){
 	      printf("giving   slot %2d frame %6d\n",frameOut,ptr->id);
 	    }
