@@ -6,7 +6,7 @@
  *
  *  Sources: some ideas from volnorm plugin for xmms
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,29 +36,15 @@
 #define MOD_NAME    "filter_normalize.so"
 #define MOD_VERSION "v0.1.1 (2002-06-18)"
 #define MOD_CAP     "Volume normalizer"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
+#define MOD_AUTHOR  "pl, Tilmann Bitterberg"
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
+#include <math.h>
+
+
 // basic parameter
 // mul is the value by which the samples are scaled
 // and has to be in [MUL_MIN, MUL_MAX]
