@@ -1,7 +1,7 @@
 /*
     filter_smartdeinter.c
     
-    This file is part of transcode, a linux video stream processing tool
+    This file is part of transcode, a video stream processing tool
     
     Smart Deinterlacing Filter for VirtualDub -- performs deinterlacing only
     in moving picture areas, allowing full resolution in static areas.
@@ -35,29 +35,15 @@
 #define MOD_NAME    "filter_smartdeinter.so"
 #define MOD_VERSION "v2.7b (2003-02-01)"
 #define MOD_CAP     "VirtualDub's smart deinterlacer"
-#define MOD_AUTHOR  "Donald Graft"
-
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#define MOD_AUTHOR  "Donald Graft, Tilmann Bitterberg"
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
+
 #include "export/vid_aux.h"
 
+
 static vob_t *vob=NULL;
 
 /* vdub compat */
@@ -298,29 +284,29 @@ int tc_filter(vframe_list_t *ptr, char *options)
       char buf[255];
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VRYE", "1");
 
-      sprintf (buf, "%d", mfd->motionOnly);
+      snprintf (buf, sizeof(buf), "%d", mfd->motionOnly);
       optstr_param (options, "motionOnly", "Show motion areas only" ,"%d", buf, "0", "1");
-      sprintf (buf, "%d", mfd->Blend);
+      snprintf (buf, sizeof(buf), "%d", mfd->Blend);
       optstr_param (options, "Blend", "Blend instead of interpolate in motion areas", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->threshold);
+      snprintf (buf, sizeof(buf), "%d", mfd->threshold);
       optstr_param (options, "threshold", "Motion Threshold", "%d", buf, "0", "255" );
-      sprintf (buf, "%d", mfd->scenethreshold);
+      snprintf (buf, sizeof(buf), "%d", mfd->scenethreshold);
       optstr_param (options, "scenethreshold", "Scene Change Threshold", "%d", buf, "0", "255" );
-      sprintf (buf, "%d", mfd->fieldShift);
+      snprintf (buf, sizeof(buf), "%d", mfd->fieldShift);
       optstr_param (options, "fieldShift", "Phase shift", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->inswap);
+      snprintf (buf, sizeof(buf), "%d", mfd->inswap);
       optstr_param (options, "inswap", "Field swap before phase shift", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->outswap);
+      snprintf (buf, sizeof(buf), "%d", mfd->outswap);
       optstr_param (options, "outswap", "Field swap after phase shift", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->noMotion);
+      snprintf (buf, sizeof(buf), "%d", mfd->noMotion);
       optstr_param (options, "noMotion", "Disable motion processing", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->highq);
+      snprintf (buf, sizeof(buf), "%d", mfd->highq);
       optstr_param (options, "highq", "Motion map denoising for field-only", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->diffmode);
+      snprintf (buf, sizeof(buf), "%d", mfd->diffmode);
       optstr_param (options, "diffmode", "Motion Detection (0=frame, 1=field, 2=both)", "%d", buf, "0", "2" );
-      sprintf (buf, "%d", mfd->colordiff);
+      snprintf (buf, sizeof(buf), "%d", mfd->colordiff);
       optstr_param (options, "colordiff", "Compare color channels instead of luma", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->cubic);
+      snprintf (buf, sizeof(buf), "%d", mfd->cubic);
       optstr_param (options, "cubic", "Use cubic for interpolation", "%d", buf, "0", "1" );
 
       return (0);
