@@ -1,7 +1,7 @@
 /*
     filter_smartyuv.c
     
-    This file is part of transcode, a linux video stream processing tool
+    This file is part of transcode, a video stream processing tool
     
     2003 by Tilmann Bitterberg, based on code by Donald Graft.
     
@@ -25,24 +25,8 @@
 #define MOD_CAP     "Motion-adaptive deinterlacing"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
 //#undef HAVE_MMX
@@ -53,11 +37,11 @@
 
 // altivec does not give much, about 1 fps
 
-#ifdef HAVE_MMX
+#ifdef HAVE_ASM_MMX
 # include "mmx.h"
 #endif
 
-#ifndef HAVE_MMX
+#ifndef HAVE_ASM_MMX
 # define emms() do{}while(0)
 #endif
 
@@ -220,7 +204,9 @@ static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int he
     int sum, x, y;
     uint8_t  *m, *fmoving, *moving, *p;
     int w4 = width+PAD;
+#ifdef HAVE_ASM_MMX
     int can_use_mmx = !(width%4);
+#endif
 
     // Erode.
     fmoving = _fmoving;
@@ -229,7 +215,7 @@ static void Erode_Dilate (uint8_t *_moving, uint8_t *_fmoving, int width, int he
 
     for (y = 0; y < height; y++)
     {
-#ifdef HAVE_MMX
+#ifdef HAVE_ASM_MMX
 	/*
 	 * The motion map as either 1 or 0.
 	 * moving[x] is the current position.
@@ -406,8 +392,12 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	unsigned char		fiMotion;
 	int			cubic = mfd->cubic;
 	static int 		counter=0;
+#ifdef HAVE_ASM_MMX
 	const int		can_use_mmx = !(w%8); // width must a multiple of 8
-	// const int		can_use_altivec = !(w%16); // width must a multiple of 16
+#endif
+#ifdef CAN_COMPILE_C_ALTIVEC
+	const int		can_use_altivec = !(w%16); // width must a multiple of 16
+#endif
 
 
 	char * dst_buf;
@@ -432,7 +422,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	{
 		if (mfd->diffmode == FRAME_ONLY) {
 
-#ifdef HAVE_MMX
+#ifdef HAVE_ASM_MMX
 		  if (can_use_mmx) {
 
 		    uint64_t mask1 = 0x00FF00FF00FF00FFULL;
@@ -580,7 +570,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 
 		} else if (mfd->diffmode == FRAME_AND_FIELD) {
 
-#ifdef HAVE_MMX
+#ifdef HAVE_ASM_MMX
 		  if (can_use_mmx) {
 
 		    uint64_t mask1 = 0x00FF00FF00FF00FFULL;
@@ -1096,7 +1086,7 @@ static void smartyuv_core (char *_src, char *_dst, char *_prev, int _width, int
 	    // linear blend, see Blendline_c for a plainC version
 	    for (y = 1; y < hminus1; y++)
 	    {
-#ifdef HAVE_MMX
+#ifdef HAVE_ASM_MMX
 	      if (can_use_mmx) {
 
 		uint64_t scmask = (scenechange<<24) | (scenechange<<16) | (scenechange<<8) | scenechange;
@@ -1438,7 +1428,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	// filter init ok.
 
 	if(verbose) printf("[%s] "
-#ifdef HAVE_MMX
+#ifdef HAVE_ASM_MMX
 		"(MMX) "
 #endif
 #ifdef CAN_COMPILE_C_ALTIVEC
@@ -1455,25 +1445,25 @@ int tc_filter(vframe_list_t *ptr, char *options)
       char buf[255];
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYE", "1");
 
-      sprintf (buf, "%d", mfd->motionOnly);
+      snprintf (buf, sizeof(buf), "%d", mfd->motionOnly);
       optstr_param (options, "motionOnly", "Show motion areas only, blacking out static areas" ,"%d", buf, "0", "1");
-      sprintf (buf, "%d", mfd->diffmode);
+      snprintf (buf, sizeof(buf), "%d", mfd->diffmode);
       optstr_param (options, "diffmode", "Motion Detection (0=frame, 1=field, 2=both)", "%d", buf, "0", "2" );
-      sprintf (buf, "%d", mfd->threshold);
+      snprintf (buf, sizeof(buf), "%d", mfd->threshold);
       optstr_param (options, "threshold", "Motion Threshold (luma)", "%d", buf, "0", "255" );
-      sprintf (buf, "%d", mfd->chromathres);
+      snprintf (buf, sizeof(buf), "%d", mfd->chromathres);
       optstr_param (options, "chromathres", "Motion Threshold (chroma)", "%d", buf, "0", "255" );
-      sprintf (buf, "%d", mfd->scenethreshold);
+      snprintf (buf, sizeof(buf), "%d", mfd->scenethreshold);
       optstr_param (options, "scenethres", "Threshold for detecting scenechanges", "%d", buf, "0", "255" );
-      sprintf (buf, "%d", mfd->highq);
+      snprintf (buf, sizeof(buf), "%d", mfd->highq);
       optstr_param (options, "highq", "High-Quality processing (motion Map denoising)", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->cubic);
+      snprintf (buf, sizeof(buf), "%d", mfd->cubic);
       optstr_param (options, "cubic", "Do cubic interpolation", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->Blend);
+      snprintf (buf, sizeof(buf), "%d", mfd->Blend);
       optstr_param (options, "Blend", "Blend the frames for deinterlacing", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->doChroma);
+      snprintf (buf, sizeof(buf), "%d", mfd->doChroma);
       optstr_param (options, "doChroma", "Enable chroma processing (slower but more accurate)", "%d", buf, "0", "1" );
-      sprintf (buf, "%d", mfd->verbose);
+      snprintf (buf, sizeof(buf), "%d", mfd->verbose);
       optstr_param (options, "verbose", "Verbose mode", "%d", buf, "0", "1" );
 
       return (0);
