@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Tilmann Bitterberg - August 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,23 +26,9 @@
 #define MOD_CAP     "video 23.9 -> 29.9 telecide filter"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
+#include "optstr.h"
 
 // this variable is for external control from transcode. Not enabled right now
 // extern int tc_do_telecide;
@@ -70,24 +56,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   if (ptr->tag & TC_AUDIO)
 	  return (0);
 
-  // API explanation:
-  // ================
-  //
-  // (1) need more infos, than get pointer to transcode global 
-  //     information structure vob_t as defined in transcode.h.
-  //
-  // (2) 'tc_get_vob' and 'verbose' are exported by transcode.
-  //
-  // (3) filter is called first time with TC_FILTER_INIT flag set.
-  //
-  // (4) make sure to exit immediately if context (video/audio) or 
-  //     placement of call (pre/post) is not compatible with the filters 
-  //     intended purpose, since the filter is called 4 times per frame.
-  //
-  // (5) see framebuffer.h for a complete list of frame_list_t variables.
-  //
-  // (6) filter is last time with TC_FILTER_CLOSE flag set
-
 
   //----------------------------------
   //
@@ -95,7 +63,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   //
   //----------------------------------
 
-
   if(ptr->tag & TC_FILTER_INIT) {
     
     if((vob = tc_get_vob())==NULL) return(-1);
@@ -123,7 +90,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // filter close
   //
   //----------------------------------
-
   
   if(ptr->tag & TC_FILTER_CLOSE) {
     return(0);
@@ -157,8 +123,8 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
     /*
     if (!tc_do_telecide) {
-	    memcpy (video_buf[0], ptr->video_buf, height*width*3/2);
-	    memcpy (video_buf[1], ptr->video_buf, height*width*3/2);
+	    tc_memcpy (video_buf[0], ptr->video_buf, height*width*3/2);
+	    tc_memcpy (video_buf[1], ptr->video_buf, height*width*3/2);
 	    return 0;
     }
     */
@@ -177,13 +143,13 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	/* save top2 lines */
 	for (y=0; y<(height+1)/2; y++) {
-	    memcpy (Y1, Y2, width);
+	    tc_memcpy (Y1, Y2, width);
 	    Y1 += width*2;
 	    Y2 += width*2;
 	}
 	/* color */
 	for (y=0; y<(height+1)/2; y++) {
-	    memcpy (Cr1, Cr2, width2);
+	    tc_memcpy (Cr1, Cr2, width2);
 	    Cr1 += width;
 	    Cr2 += width;
 	}
@@ -198,13 +164,13 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	/* save top3 lines */
 	for (y=0; y<(height+1)/2; y++) {
-	    memcpy (Y1, Y2, width);
+	    tc_memcpy (Y1, Y2, width);
 	    Y1 += width*2;
 	    Y2 += width*2;
 	}
 	/* color */
 	for (y=0; y<(height+1)/2; y++) {
-	    memcpy (Cr1, Cr2, width2);
+	    tc_memcpy (Cr1, Cr2, width2);
 	    Cr1 += width;
 	    Cr2 += width;
 	}
@@ -217,13 +183,13 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	/* merge bot3 with top2 */
 	for (y=0; y<(height+1)/2; y++) {
-	    memcpy (Y1, Y2, width);
+	    tc_memcpy (Y1, Y2, width);
 	    Y1 += width*2;
 	    Y2 += width*2;
 	}
 	/* color */
 	for (y=0; y<(height+1)/2; y++) {
-	    memcpy (Cr1, Cr2, width2);
+	    tc_memcpy (Cr1, Cr2, width2);
 	    Cr1 += width;
 	    Cr2 += width;
 	}
@@ -233,7 +199,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	    ptr->attributes |= TC_FRAME_IS_CLONED;
 
 	    /* save complete frame */
-	    memcpy (video_buf[0], ptr->video_buf, height*width*3/2);
+	    tc_memcpy (video_buf[0], ptr->video_buf, height*width*3/2);
 
 	    /* merge bot4 with top3 */
 	    Y1 = ptr->video_buf;
@@ -243,20 +209,20 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	    Cr2 = video_buf[1]+wh;
 
 	    for (y=0; y<(height+1)/2; y++) {
-		memcpy (Y1, Y2, width);
+		tc_memcpy (Y1, Y2, width);
 		Y1 += width*2;
 		Y2 += width*2;
 	    }
 	    /* color */
 	    for (y=0; y<(height+1)/2; y++) {
-		memcpy (Cr1, Cr2, width2);
+		tc_memcpy (Cr1, Cr2, width2);
 		Cr1 += width;
 		Cr2 += width;
 	    }
 	} else {
 	    /* restore frame4 = frame 5 */
 	    // this is the cloned frame
-	    memcpy (ptr->video_buf, video_buf[0], height*width*3/2);
+	    tc_memcpy (ptr->video_buf, video_buf[0], height*width*3/2);
 	}
 	break;
     } // switch mod
@@ -277,30 +243,30 @@ int tc_filter(vframe_list_t *ptr, char *options)
       case 2:
 	/* save top2 lines */
 	for (y=0; y<height-1; y+=2) 
-	  memcpy (video_buf[0]+y*width3, ptr->video_buf+y*width3, width3);
+	  tc_memcpy (video_buf[0]+y*width3, ptr->video_buf+y*width3, width3);
 	break;
       case 3:
 	/* save top3 lines */
 	for (y=0; y<height-1; y+=2) 
-	  memcpy (video_buf[1]+y*width3, ptr->video_buf+y*width3, width3);
+	  tc_memcpy (video_buf[1]+y*width3, ptr->video_buf+y*width3, width3);
 	
 	/* merge bot3 with top2 */
 	for (y=0; y<height-1; y+=2) 
-	  memcpy (ptr->video_buf+y*width3, video_buf[0]+y*width3, width3);
+	  tc_memcpy (ptr->video_buf+y*width3, video_buf[0]+y*width3, width3);
 	break;
       case 0:
 	if (!(ptr->attributes & TC_FRAME_WAS_CLONED)) {
 	    ptr->attributes |= TC_FRAME_IS_CLONED;
 
 	    /* save complete frame */
-	    memcpy (video_buf[0], ptr->video_buf, height*width3);
+	    tc_memcpy (video_buf[0], ptr->video_buf, height*width3);
 	    /* merge bot4 with top3 */
 	    for (y=0; y<height-1; y+=2) 
-		memcpy (ptr->video_buf+y*width3, video_buf[1]+y*width3, width3);
+		tc_memcpy (ptr->video_buf+y*width3, video_buf[1]+y*width3, width3);
 	} else {
 	    /* restore frame4 = frame 5 */
 	    // this is the cloned frame
-	    memcpy (ptr->video_buf, video_buf[0], height*width3);
+	    tc_memcpy (ptr->video_buf, video_buf[0], height*width3);
 	}
 	break;
     } // switch mod
