@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,24 +24,10 @@
 #define MOD_NAME    "filter_testframe.so"
 #define MOD_VERSION "v0.1.3 (2003-09-04)"
 #define MOD_CAP     "generate stream of testframes"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#define MOD_AUTHOR  "Thomas Oestreich"
 
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
 static int mode=0;
@@ -184,25 +170,6 @@ static int is_optstr(char *options)
 int tc_filter(vframe_list_t *ptr, char *options)
 {
 
-  // API explanation:
-  // ================
-  //
-  // (1) need more infos, than get pointer to transcode global 
-  //     information structure vob_t as defined in transcode.h.
-  //
-  // (2) 'tc_get_vob' and 'verbose' are exported by transcode.
-  //
-  // (3) filter is called first time with TC_FILTER_INIT flag set.
-  //
-  // (4) make sure to exit immediately if context (video/audio) or 
-  //     placement of call (pre/post) is not compatible with the filters 
-  //     intended purpose, since the filter is called 4 times per frame.
-  //
-  // (5) see framebuffer.h for a complete list of frame_list_t variables.
-  //
-  // (6) filter is last time with TC_FILTER_CLOSE flag set
-
-
   if(ptr->tag & TC_FILTER_GET_CONFIG) {
 
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, "Thomas Oestreich", "VRYE", "1");
@@ -215,7 +182,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   //
   //----------------------------------
 
-
   if(ptr->tag & TC_FILTER_INIT) {
     
     if((vob = tc_get_vob())==NULL) return(-1);
@@ -244,7 +210,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
   //
   //----------------------------------
 
-  
   if(ptr->tag & TC_FILTER_CLOSE) {
     return(0);
   }
