@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Tilmann Bitterberg - April 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,22 +26,11 @@
 #define MOD_CAP     "write text in the image"
 #define MOD_AUTHOR  "Tilmann Bitterberg"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
+#include "transcode.h"
+#include "filter.h"
+#include "optstr.h"
 
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
-#include <inttypes.h>
+#include "video_trans.h"
 
 // FreeType specific includes
 #include <ft2build.h>
@@ -49,11 +38,6 @@
 #include FT_FREETYPE_H
 
 
-#include "transcode.h"
-#include "framebuffer.h"
-#include "optstr.h"
-#include "video_trans.h"
-
 // basic parameter
 
 enum POS { NONE, TOP_LEFT, TOP_RIGHT, BOT_LEFT, BOT_RIGHT, CENTER, BOT_CENTER };
@@ -94,6 +78,7 @@ typedef struct MyFilterData {
 	char *string;        /* text to display */
 	int fade;            /* fade in/out (speed) */
 	int transparent;     /* do not draw a black bounding box */
+	int tstamp;          /* */
 	int antialias;       /* do sub frame anti-aliasing (not done) */
 	int R, G, B;         /* color to apply in RGB */
 	int Y, U, V;         /* color to apply in YUV */
@@ -132,6 +117,84 @@ static void help_optstr(void)
    printf (" 'notransparent' disable transparency\n");
    printf ("           'pos' Position (0-width x 0-height) [0x0]\n");
    printf ("        'posdef' Position (0=None 1=TopL 2=TopR 3=BotL 4=BotR 5=Cent 6=BotCent) [0]\n");
+   printf ("        'tstamp' add timestamp to each frame (overrides string)\n");
+}
+
+static void font_render(int width, int height, int size, int codec, int w, int h, int i, char *p, char *q, char *buf)
+{
+    int error;
+
+    //render into temp buffer
+    if (codec == CODEC_YUV) {
+
+        memset (buf, 16, height*width);
+        memset (buf+height*width, 128, height*width/2);
+	p = buf+mfd->posy*width+mfd->posx;
+
+	for (i=0; i<strlen(mfd->string); i++) {
+
+	    error = FT_Load_Char( mfd->face, mfd->string[i], FT_LOAD_RENDER);
+	    mfd->slot = mfd->face->glyph;
+
+	    if (verbose > 1) {
+		// see http://www.freetype.org/freetype2/docs/tutorial/metrics.png
+		/*
+		printf ("`%c\': rows(%2d) width(%2d) pitch(%2d) left(%2d) top(%2d) "
+			"METRIC: width(%2d) height(%2d) bearX(%2d) bearY(%2d)\n",
+			mfd->string[i], mfd->slot->bitmap.rows, mfd->slot->bitmap.width, 
+			mfd->slot->bitmap.pitch, mfd->slot->bitmap_left, mfd->slot->bitmap_top,
+			mfd->slot->metrics.width>>6, mfd->slot->metrics.height>>6,
+			mfd->slot->metrics.horiBearingX>>6, mfd->slot->metrics.horiBearingY>>6);
+			*/
+	    }
+
+	    for (h=0; h<mfd->slot->bitmap.rows; h++) {
+		for (w=0; w<mfd->slot->bitmap.width; w++)  {
+		    unsigned char c = mfd->slot->bitmap.buffer[h*mfd->slot->bitmap.width+w] &0xff;
+		    c = yuv255to224[c];
+		    // make it transparent
+		    if (mfd->transparent && c==16) continue;
+
+		    p[width*(h+mfd->top_space - mfd->slot->bitmap_top) + 
+			w+mfd->slot->bitmap_left] = c&0xff;
+
+		    }
+		}
+	    p+=((mfd->slot->advance.x >> 6) - (mfd->slot->advance.y >> 6)*width);
+	} 
+
+    } else if (codec == CODEC_RGB) {
+
+        memset (buf, 0, height*size);
+	p = buf + 3*(height-mfd->posy)*width + 3*mfd->posx;
+
+	for (i=0; i<strlen(mfd->string); i++) {
+
+	    // render the char
+	    error = FT_Load_Char( mfd->face, mfd->string[i], FT_LOAD_RENDER);
+	    mfd->slot = mfd->face->glyph; // shortcut
+
+	    for (h=0; h<mfd->slot->bitmap.rows; h++) {
+		for (w=0; w<mfd->slot->bitmap.width; w++)  {
+		    unsigned char c = mfd->slot->bitmap.buffer[h*mfd->slot->bitmap.width+w];
+		    c = c>254?254:c;
+		    c = c<16?16:c;
+		    // make it transparent
+		    if (mfd->transparent && c==16) continue;
+
+		    p[3*(width*(-(h+mfd->top_space - mfd->slot->bitmap_top)) + 
+			    w+mfd->slot->bitmap_left)-2] = c&0xff;
+		    p[3*(width*(-(h+mfd->top_space - mfd->slot->bitmap_top)) + 
+			    w+mfd->slot->bitmap_left)-1] = c&0xff;
+		    p[3*(width*(-(h+mfd->top_space - mfd->slot->bitmap_top)) + 
+			    w+mfd->slot->bitmap_left)-0] = c&0xff;
+
+		    }
+		}
+
+	    p+=3*((mfd->slot->advance.x >> 6) - (mfd->slot->advance.y >> 6));
+	}
+    }
 }
 
 /*-------------------------------------------------
@@ -147,11 +210,13 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
   static int width=0, height=0;
   static int size, codec=0;
-  int w, h, i;
+  static int w, h, i;
   int error;
-  time_t mytime = time(NULL);
+  static time_t mytime=0;
+  static int hh, mm, ss, ss_frame;
+  static float elapsed_ss;
   static char *buf = NULL;
-  char *p, *q;
+  static char *p, *q;
   char *default_font = "/usr/X11R6/lib/X11/fonts/TrueType/arial.ttf";
   extern int flip; // transcode.c
   
@@ -194,6 +259,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
       optstr_param (options, "posdef", "Position (0=None 1=TopL 2=TopR 3=BotL 4=BotR 5=Cent 6=BotCent)",  "%d", "0", "0", "5");
 
       optstr_param (options, "notransparent", "disable transparency (enables block box)", "", "0");
+      optstr_param (options, "tstamp", "add timestamp to each frame (overrides string)", "", "0");
 
       return 0;
   }
@@ -231,6 +297,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
     mfd->antialias=1;
 
     mfd->do_time=1;
+    mfd->tstamp=0;
     mfd->opaque=MAX_OPACITY;
     mfd->fade_in = 0;
     mfd->fade_out = 0;
@@ -247,10 +314,6 @@ int tc_filter(vframe_list_t *ptr, char *options)
     mfd->Y = 240; mfd->U = mfd->V = 128;
 
 
-    // do `date` as default
-    mytime = time(NULL);
-    mfd->string = ctime(&mytime);
-    mfd->string[strlen(mfd->string)-1] = '\0';
 
     if (options != NULL) {
 	char font[PATH_MAX];
@@ -275,8 +338,9 @@ int tc_filter(vframe_list_t *ptr, char *options)
         mfd->U =  (0.439 * mfd->R) - (0.368 * mfd->G) - (0.071 * mfd->B) + 128;
         mfd->V = -(0.148 * mfd->R) - (0.291 * mfd->G) + (0.439 * mfd->B) + 128;
 
-	if (optstr_lookup (options, "notransparent") )
+	if (optstr_lookup (options, "notransparent") ) {
 	    mfd->transparent = !mfd->transparent;
+        }
 
 	if (font && strlen(font)>0) {
 	    free (mfd->font);
@@ -286,10 +350,20 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	if (string && strlen(string)>0) {
 	    mfd->string=strdup(string);
 	    mfd->do_time=0;
-	}
-	   
-    }
+        }
+        else if (optstr_lookup (options, "tstamp") ) {
+	    // mytime = time(NULL);
+            mfd->string=strdup("[ timestamp ]");
+	    mfd->do_time = 0;
+	    mfd->tstamp = 1;
 
+	} else {
+	    // do `date` as default
+	    mytime = time(NULL);
+	    mfd->string = ctime(&mytime);
+	    mfd->string[strlen(mfd->string)-1] = '\0';
+	}
+    }
 
     if (verbose) {
 	printf (" Text Settings:\n");
@@ -424,75 +498,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	return (-1);
     }
 
-
-    //render into temp buffer
-    if (codec == CODEC_YUV) {
-
-	p = buf+mfd->posy*width+mfd->posx;
-
-	for (i=0; i<strlen(mfd->string); i++) {
-
-	    error = FT_Load_Char( mfd->face, mfd->string[i], FT_LOAD_RENDER);
-	    mfd->slot = mfd->face->glyph;
-
-	    if (verbose > 1) {
-		// see http://www.freetype.org/freetype2/docs/tutorial/metrics.png
-		/*
-		printf ("`%c\': rows(%2d) width(%2d) pitch(%2d) left(%2d) top(%2d) "
-			"METRIC: width(%2d) height(%2d) bearX(%2d) bearY(%2d)\n",
-			mfd->string[i], mfd->slot->bitmap.rows, mfd->slot->bitmap.width, 
-			mfd->slot->bitmap.pitch, mfd->slot->bitmap_left, mfd->slot->bitmap_top,
-			mfd->slot->metrics.width>>6, mfd->slot->metrics.height>>6,
-			mfd->slot->metrics.horiBearingX>>6, mfd->slot->metrics.horiBearingY>>6);
-			*/
-	    }
-
-	    for (h=0; h<mfd->slot->bitmap.rows; h++) {
-		for (w=0; w<mfd->slot->bitmap.width; w++)  {
-		    unsigned char c = mfd->slot->bitmap.buffer[h*mfd->slot->bitmap.width+w] &0xff;
-		    c = yuv255to224[c];
-		    // make it transparent
-		    if (mfd->transparent && c==16) continue;
-
-		    p[width*(h+mfd->top_space - mfd->slot->bitmap_top) + 
-			w+mfd->slot->bitmap_left] = c&0xff;
-
-		    }
-		}
-	    p+=((mfd->slot->advance.x >> 6) - (mfd->slot->advance.y >> 6)*width);
-	} 
-
-    } else if (codec == CODEC_RGB) {
-
-	p = buf + 3*(height-mfd->posy)*width + 3*mfd->posx;
-
-	for (i=0; i<strlen(mfd->string); i++) {
-
-	    // render the char
-	    error = FT_Load_Char( mfd->face, mfd->string[i], FT_LOAD_RENDER);
-	    mfd->slot = mfd->face->glyph; // shortcut
-
-	    for (h=0; h<mfd->slot->bitmap.rows; h++) {
-		for (w=0; w<mfd->slot->bitmap.width; w++)  {
-		    unsigned char c = mfd->slot->bitmap.buffer[h*mfd->slot->bitmap.width+w];
-		    c = c>254?254:c;
-		    c = c<16?16:c;
-		    // make it transparent
-		    if (mfd->transparent && c==16) continue;
-
-		    p[3*(width*(-(h+mfd->top_space - mfd->slot->bitmap_top)) + 
-			    w+mfd->slot->bitmap_left)-2] = c&0xff;
-		    p[3*(width*(-(h+mfd->top_space - mfd->slot->bitmap_top)) + 
-			    w+mfd->slot->bitmap_left)-1] = c&0xff;
-		    p[3*(width*(-(h+mfd->top_space - mfd->slot->bitmap_top)) + 
-			    w+mfd->slot->bitmap_left)-0] = c&0xff;
-
-		    }
-		}
-
-	    p+=3*((mfd->slot->advance.x >> 6) - (mfd->slot->advance.y >> 6));
-	}
-    }
+    font_render(width,height,size,codec,w,h,i,p,q,buf);
 
     // filter init ok.
     if (verbose) printf("[%s] %s %s %dx%d-%d\n", MOD_NAME, MOD_VERSION, MOD_CAP, 
@@ -543,6 +549,23 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
     if (mfd->start <= ptr->id && ptr->id <= mfd->end && ptr->id%mfd->step == mfd->boolstep) {
 
+	if(mfd->do_time && time(NULL)!=mytime) {
+	    mytime = time(NULL);
+	    mfd->string = ctime(&mytime);
+	    mfd->string[strlen(mfd->string)-1] = '\0';
+	    font_render(width,height,size,codec,w,h,i,p,q,buf);
+	}
+
+	else if (mfd->tstamp) {
+	    elapsed_ss = ptr->id / vob->fps;
+	    hh = elapsed_ss / 3600;
+	    mm = (elapsed_ss - (3600 * hh)) / 60;
+	    ss = (elapsed_ss - (3600 * hh) - (60 * mm));
+	    ss_frame = (ptr->id - (((hh * 3600) + (mm * 60) + ss) * vob->fps));
+	    sprintf(mfd->string, "%02i:%02i:%02i.%02i", hh, mm, ss, ss_frame);  
+	    font_render(width,height,size,codec,w,h,i,p,q,buf);
+	}
+
 	if (mfd->start == ptr->id && mfd->fade) {
 	    mfd->fade_in = 1;
 	    mfd->fade_out= 0;
