@@ -1,7 +1,7 @@
 /*
     filter_whitebalance.c
     
-    This file is part of transcode, a linux video stream processing tool
+    This file is part of transcode, a video stream processing tool
     
     White Balance Filter - correct images with a broken white balance
     (typically, images from a dv camcorder with an unset white balance or
@@ -29,27 +29,15 @@
 #define MOD_CAP     "White Balance Filter - correct images with a broken white balance"
 #define MOD_AUTHOR  "Guillaume Cottenceau"
 
-#include <unistd.h>
-#include <stdlib.h>
-#include <stdio.h>
+#include "transcode.h"
+#include "filter.h"
+#include "optstr.h"
+
+#include "export/vid_aux.h"
+
 #include <math.h>
 #include <ctype.h>
 
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include "transcode.h"
-#include "framebuffer.h"
-#include "optstr.h"
-#include "export/vid_aux.h"
-
 static unsigned char * buffer = NULL;
 static int level = 40;
 static char limit[PATH_MAX];
