@@ -4,7 +4,7 @@
     Copyright (C) 1999-2000 Donald A. Graft
       modified 2002 by Tilmann Bitterberg for use with transcode
    
-    This file is part of transcode, a linux video stream processing tool
+    This file is part of transcode, a video stream processing tool
 
     Xsharpen Filter for VirtualDub -- sharpen by mapping pixels
     to the closest of window max or min. 
@@ -33,24 +33,8 @@
 #define MOD_CAP     "VirtualDub's XSharpen Filter"
 #define MOD_AUTHOR  "Donald Graft, Tilmann Bitterberg"
 
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "transcode.h"
-#include "framebuffer.h"
+#include "filter.h"
 #include "optstr.h"
 
 static vob_t *vob=NULL;
@@ -228,10 +212,10 @@ int tc_filter(vframe_list_t *ptr, char *options)
     if (options) {
 	    char buf[256];
 	    optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VRYO", "1");
-	    sprintf (buf, "%d", mfd->strength);
+	    snprintf (buf, sizeof(buf), "%d", mfd->strength);
 	    optstr_param (options, "strength", "How much  of the effect", "%d", buf, "0", "255");
 
-	    sprintf (buf, "%d", mfd->threshold);
+	    snprintf (buf, sizeof(buf), "%d", mfd->threshold);
 	    optstr_param (options, "threshold", 
 			  "How close a pixel must be to the brightest or dimmest pixel to be mapped", 
 			  "%d", buf, "0", "255");
