@@ -8,7 +8,7 @@
  *     Copyright (C) Erik Walthinsen - April 2000
  *  part of libdv, a free DV (IEC 61834/SMPTE 314M) codec.
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,21 +26,14 @@
  *
  */
 
-#include <unistd.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <math.h>
-#include <string.h>
 
 #include "pv.h"
 #include "src/socket.h"
 
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#include <math.h>
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 
 // FIXME: Use autoconf for this!!
 #ifdef SYS_BSD /* We don't have on_exit() */
@@ -274,7 +267,7 @@ void xv_display_event (xv_display_t *dv_dpy)
 	      int yend = (y1>y2)?y1:y2;
 	      char buf[255];
 
-	      sprintf(buf, "[%s]: pos1=%dx%d pos2=%dx%d pos=%dx%d:size=%dx%d -Y %d,%d,%d,%d\n", 
+	      snprintf(buf, sizeof(buf), "[%s]: pos1=%dx%d pos2=%dx%d pos=%dx%d:size=%dx%d -Y %d,%d,%d,%d\n", 
 			      "filter_pv", xanf, yanf, xend, yend, xanf, yanf, xend-xanf, yend-yanf, 
 			      yanf, xanf,  dv_dpy->height-yend, dv_dpy->width - xend);
 
