@@ -16,6 +16,9 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "subtitler.h"
 
+struct frame *frametab[FRAME_HASH_SIZE];
+struct subtitle_fontname *subtitle_fontnametab[2];
+
 extern int parse_frame_entry(struct frame *pa);
 
 int hash(s)/* form hash value for string s */
@@ -35,7 +38,7 @@ return(hashval % FRAME_HASH_SIZE);
 char *strsave(char *s) /*save char array s somewhere*/
 {
 char *p;
-if((p = malloc( strlen(s) +  1))) strcpy(p, s);
+if((p = malloc( strlen(s) +  1))) strlcpy(p, s, strlen(s) + 1);
 return(p);
 }
 
@@ -179,7 +182,7 @@ if(debug_flag)
 	frame_nr); 
 	}
 
-sprintf(temp, "%d", frame_nr);
+snprintf(temp, sizeof(temp), "%d", frame_nr);
 for(pa = frametab[hash(temp)]; pa != 0; pa = pa -> nxtentr)
 	{
 	if(strcmp(pa -> name, temp) == 0)
@@ -204,7 +207,7 @@ if(debug_flag)
 	frame_nr, end_frame);
 	}
 
-sprintf(temp, "%d", frame_nr);
+snprintf(temp, sizeof(temp), "%d", frame_nr);
 for(pa = frametab[hash(temp)]; pa != 0; pa = pa -> nxtentr)
 	{
 #if 0
@@ -288,7 +291,7 @@ if(debug_flag)
 	fprintf(stdout, "delete_subtitle_fontname(): arg subtitle_fontnamenr=%d\n", subtitle_fontnamenr);
 	}
 
-sprintf(name, "%d", subtitle_fontnamenr);
+snprintf(name, sizeof(name), "%d", subtitle_fontnamenr);
 pa = subtitle_fontnametab[0];
 while(1)
 	{
@@ -370,7 +373,7 @@ if(debug_flag)
 	name, symbols, size, iso_extension, outline_thickness, blur_radius);
 	}
 
-sprintf(temp, "%s_%d_%d_%d_%.2f_%.2f", name, symbols, size, iso_extension, outline_thickness, blur_radius);
+snprintf(temp, sizeof(temp), "%s_%d_%d_%d_%.2f_%.2f", name, symbols, size, iso_extension, outline_thickness, blur_radius);
 ps = lookup_subtitle_fontname(temp);
 if(ps) /* found in list */
 	{
@@ -403,7 +406,7 @@ else /* not in fontname_list */
 			return 0;
 			}
 
-		sprintf(temp, "%s_%d_%d_%d_%.2f_%.2f",\
+		snprintf(temp, sizeof(temp), "%s_%d_%d_%d_%.2f_%.2f",\
 			default_subtitle_font_name,\
 			default_subtitle_symbols,\
 			default_subtitle_font_size,\
