@@ -70,9 +70,9 @@ extern raw_file* load_raw(char *name,int verbose);
 extern font_desc_t* read_font_desc(char* fname,float factor,int verbose);
 extern int readline_msdos(FILE *file, char *contents);
 extern int load_ssa_file(char *pathfilename);
-extern read_in_ssa_file(FILE *finptr);
+extern void read_in_ssa_file(FILE *finptr);
 extern int load_ppml_file(char *pathfilename);
-extern read_in_ppml_file(FILE *finptr);
+extern int read_in_ppml_file(FILE *finptr);
 extern struct object *lookup_object(char *name);
 extern struct object *install_object_at_end_of_list(char *name);
 extern int delete_object(char *name);
