@@ -4,7 +4,7 @@
  *  Copyright (C) Tilmann Bitterberg, July 2002
  *                based on work by Stefan Fendt
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,28 +27,12 @@
 #define MOD_CAP     "mjpegs YUV denoiser"
 #define MOD_AUTHOR  "Stefan Fendt, Tilmann Bitterberg"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
+#include "transcode.h"
+#include "filter.h"
 #include "optstr.h"
 
-/* -------------------------------------------------
- *
- * mandatory include files
- *
- *-------------------------------------------------*/
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-#include <unistd.h>
 #include <inttypes.h>
 
-#include "transcode.h"
-#include "framebuffer.h"
-
 #include "mjpeg_types.h"
 #include "libvo/mm_accel.h"
 
@@ -108,55 +92,55 @@ int tc_filter(vframe_list_t *ptr, char *options)
   if (ptr->tag & TC_FILTER_GET_CONFIG && options) {
       char buf[255];
 
-      sprintf (buf, "%d", denoiser.delay); // frames_needed
+      snprintf (buf, sizeof(buf), "%d", denoiser.delay); // frames_needed
       optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYEO", buf);
 
-      sprintf (buf, "%d", denoiser.radius);
+      snprintf (buf, sizeof(buf), "%d", denoiser.radius);
       optstr_param (options, "radius",         "Search radius", "%d", buf, "8", "24");
 
-      sprintf (buf, "%d", denoiser.threshold);
+      snprintf (buf, sizeof(buf), "%d", denoiser.threshold);
       optstr_param (options, "threshold",      "Denoiser threshold", "%d", buf, "0", "255");
 
-      sprintf (buf, "%d", denoiser.pp_threshold);
+      snprintf (buf, sizeof(buf), "%d", denoiser.pp_threshold);
       optstr_param (options, "pp_threshold",   "Pass II threshold", "%d",  buf, "0", "255");
 
-      sprintf (buf, "%d", denoiser.delay);
+      snprintf (buf, sizeof(buf), "%d", denoiser.delay);
       optstr_param (options, "delay",          "Average 'n' frames for a time-lowpassed pixel", "%d", buf, "1", "255"  );
 
-      sprintf (buf, "%d", denoiser.postprocess);
+      snprintf (buf, sizeof(buf), "%d", denoiser.postprocess);
       optstr_param (options, "postprocess",    "Filter internal postprocessing", "%d", buf, "0", "1"  );
 
-      sprintf (buf, "%d", denoiser.luma_contrast);
+      snprintf (buf, sizeof(buf), "%d", denoiser.luma_contrast);
       optstr_param (options, "luma_contrast",  "Luminance contrast in percent", "%d", buf, "0", "255" );
 
-      sprintf (buf, "%d", denoiser.chroma_contrast);
+      snprintf (buf, sizeof(buf), "%d", denoiser.chroma_contrast);
       optstr_param (options, "chroma_contrast","Chrominance contrast in percent.", "%d", buf, "0", "255" );
 
-      sprintf (buf, "%d", denoiser.sharpen);
+      snprintf (buf, sizeof(buf), "%d", denoiser.sharpen);
       optstr_param (options, "sharpen",        "Sharpness in percent", "%d", buf, "0", "255"  );
 
-      sprintf (buf, "%d", denoiser.deinterlace);
+      snprintf (buf, sizeof(buf), "%d", denoiser.deinterlace);
       optstr_param (options, "deinterlace",    "Force deinterlacing", "%d", buf, "0", "1" );
 
-      sprintf (buf, "%d", denoiser.mode);
+      snprintf (buf, sizeof(buf), "%d", denoiser.mode);
       optstr_param (options, "mode",           "[0]: Progressive [1]: Interlaced [2]: Fast", "%d", buf, "0", "2" );
 
-      sprintf (buf, "%d", denoiser.scene_thres);
+      snprintf (buf, sizeof(buf), "%d", denoiser.scene_thres);
       optstr_param (options, "scene_thres",    "Blocks where motion estimation should fail before scenechange", "%d%%", buf, "0", "100" );
 
-      sprintf (buf, "%d", denoiser.block_thres);
+      snprintf (buf, sizeof(buf), "%d", denoiser.block_thres);
       optstr_param (options, "block_thres",    "Every SAD value greater than this will be considered bad", "%d", buf, "0", "oo" );
 
-      sprintf (buf, "%d", denoiser.do_reset);
+      snprintf (buf, sizeof(buf), "%d", denoiser.do_reset);
       optstr_param (options, "do_reset",       "Reset the filter for `n' frames after a scene", "%d", buf, "0", "oo" );
 
-      sprintf (buf, "%d", denoiser.increment_cr);
+      snprintf (buf, sizeof(buf), "%d", denoiser.increment_cr);
       optstr_param (options, "increment_cr",   "Increment Cr with constant", "%d", buf, "-128", "127" );
 
-      sprintf (buf, "%d", denoiser.increment_cb);
+      snprintf (buf, sizeof(buf), "%d", denoiser.increment_cb);
       optstr_param (options, "increment_cb",   "Increment Cb with constant", "%d", buf, "-128", "127"  );
 
-      sprintf (buf, "%dx%d-%dx%d", 
+      snprintf (buf, sizeof(buf), "%dx%d-%dx%d", 
 	denoiser.border.x, denoiser.border.y, denoiser.border.w, denoiser.border.h);
       optstr_param (options, "border",         "Active image area", "%dx%d-%dx%d", buf, "0", "W", "0", "H", "0", "W", "0", "H");
 
