@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,10 +24,6 @@
 //undef if you experience lock ups!
 #define USE_FIFO_LOGFILE 1
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
 #include "transcode.h"
 #include "ioaux.h"
 #include "clone.h"
