@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,16 +21,9 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "transcode.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
 
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
@@ -40,10 +33,8 @@
 # endif
 #endif
 
-#include "transcode.h"
 #include "ioaux.h"
 
-static int verbose;
 static char *mod_path=MOD_PATH;
 
 #define MODULE "a52_decore.so"
@@ -59,7 +50,7 @@ int a52_do_init(char *path) {
 #endif    
     char *error;
 
-    sprintf(module, "%s/%s", path, MODULE);
+    snprintf(module, sizeof(module), "%s/%s", path, MODULE);
   
     if(verbose & TC_DEBUG) 
 	fprintf(stderr, "loading external module %s\n", module); 
