@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,20 +21,14 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
+#include "transcode.h"
 
-#include "config.h"
+#include <sys/errno.h>
 
 #ifdef HAVE_LIBDV
 #include <libdv/dv.h>
 #endif
 
-#include "transcode.h"
 #include "ioaux.h"
 
 #define DV_PAL_SIZE    frame_size_625_50
@@ -47,7 +41,6 @@ static const int frame_size_525_60 = 10 * 150 * 80;
 static const int frame_size_625_50 = 12 * 150 * 80;
 #endif
 
-static int verbose=TC_QUIET;
 
 #ifdef HAVE_LIBDV
 static unsigned char *bufalloc(size_t size)
@@ -144,7 +137,7 @@ void decode_dv(decode_t *decode)
   static dv_decoder_t *dv_decoder=NULL;
   int error=0, dvinfo=0; 
   unsigned char  *buf, *source;
-  unsigned char  *video[3];
+  unsigned char  *video[4];
   int16_t *audio_buffers[4], *audio;  
   uint16_t pitches[3];  //do not change to signed! (ThOe) libdv BUG! 
 
@@ -152,18 +145,10 @@ void decode_dv(decode_t *decode)
 
   // Initialize DV decoder
 
-#ifdef LIBDV_095
   if((dv_decoder = dv_decoder_new(FALSE, FALSE, FALSE))==NULL) {
     fprintf(stderr, "(%s) dv decoder init failed\n", __FILE__);
     import_exit(1);
   }
-#else
-  if((dv_decoder = dv_decoder_new())==NULL) {
-    fprintf(stderr, "(%s) dv decoder init failed\n", __FILE__);
-    import_exit(1);
-  }
-  dv_init();
-#endif
   
   switch (decode->quality) {
       
@@ -251,7 +236,7 @@ void decode_dv(decode_t *decode)
 
       // print info:
       if(!dvinfo && verbose && (decode->format != TC_CODEC_PCM)) {
-	fprintf(stderr, "(%s) %s video: %dx%d framesize=%d sampling=%d\n", __FILE__, ((dv_decoder->system==e_dv_system_625_50)?"PAL":"NTSC"), dv_decoder->width, dv_decoder->height, dv_decoder->frame_size, dv_decoder->sampling);
+	fprintf(stderr, "(%s) %s video: %dx%d framesize=%lu sampling=%d\n", __FILE__, ((dv_decoder->system==e_dv_system_625_50)?"PAL":"NTSC"), dv_decoder->width, dv_decoder->height, (unsigned long)dv_decoder->frame_size, dv_decoder->sampling);
 	dvinfo=1;
       }
       
@@ -404,20 +389,11 @@ void probe_dv(info_t *ipipe)
   int bytes;
 
   // initialize DV decoder
-#ifdef LIBDV_095    
     if((dv_decoder = dv_decoder_new(TRUE, FALSE, FALSE))==NULL) {
 	fprintf(stderr, "(%s) dv decoder init failed\n", __FILE__);
 	    ipipe->error=1;
 	    return;
     }
-#else
-    if((dv_decoder = dv_decoder_new())==NULL) {
-	fprintf(stderr, "(%s) dv decoder init failed\n", __FILE__);
-	ipipe->error=1;
-	return;	
-    }
-    dv_init();
-#endif
 
   // max frame input buffer
   if((buf = (unsigned char*) calloc(1, DV_PAL_SIZE))==NULL) {
