@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,19 +21,13 @@
  *
  */
 
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
-
 #include "transcode.h"
+
+#include <sys/errno.h>
+
 #include "ioaux.h"
 
-#ifdef LAME_3_89
+#ifdef HAVE_LAME
 #include "mpg123.h"
 #endif
 
@@ -41,7 +35,6 @@
 short buffer[MP3_PCM_SIZE<<2];
 short ch1[MP3_PCM_SIZE], ch2[MP3_PCM_SIZE];
 
-static int verbose;
 
 /* why there are decode_mp3 and decode_mp2 which are very similar?
  * It is possible that lame_decode_initfile() when looking for an MP3 syncbyte
@@ -58,11 +51,12 @@ static int verbose;
 
 void decode_mp3(decode_t *decode)
 {
-  
-#ifdef LAME_3_89
- 
+
+#ifdef HAVE_LAME
+
   int samples=0, j, bytes, channels=0, i, padding=0, c;
-  
+  int verbose;
+
   mp3data_struct *mp3data;
   
   FILE *in_file;
@@ -117,7 +111,7 @@ void decode_mp3(decode_t *decode)
     j=0;
     switch (channels) {
     case 1: // mono
-      memcpy (buffer, ch1, samples*sizeof(short));
+      tc_memcpy (buffer, ch1, samples*sizeof(short));
       break;
     case 2: // stereo
     for(i=0; i < samples; i++) {
@@ -135,20 +129,21 @@ void decode_mp3(decode_t *decode)
   }
 
   import_exit(0);
-  
-#endif
 
-  fprintf(stderr, "(%s) no support for MP123 decoding configured - exit.\n", __FILE__);
+#else  // HAVE_LAME
+  fprintf(stderr, "(%s) no lame support available\n", __FILE__);
   import_exit(1);
+#endif
   
 }
 
 void decode_mp2(decode_t *decode)
 {
   
-#ifdef LAME_3_89
- 
+#ifdef HAVE_LAME
+
   int samples=0, j, bytes, channels=0, i;
+  int verbose;
   
   mp3data_struct *mp3data;
   
@@ -188,7 +183,7 @@ void decode_mp2(decode_t *decode)
     j=0;
     switch (channels) {
     case 1: // mono
-      memcpy (buffer, ch1, samples*sizeof(short));
+      tc_memcpy (buffer, ch1, samples*sizeof(short));
       break;
     case 2: // stereo
     for(i=0; i < samples; i++) {
@@ -206,10 +201,12 @@ void decode_mp2(decode_t *decode)
   }
 
   import_exit(0);
-  
+
+#else  // HAVE_LAME
+  fprintf(stderr, "(%s) no lame support available\n", __FILE__);
+  import_exit(1);
 #endif
 
-  fprintf(stderr, "(%s) no support for MP123 decoding configured - exit.\n", __FILE__);
-  import_exit(1);
 }
   
+
