@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream  processing tool
+ *  This file is part of transcode, a video stream  processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,6 @@
 #ifndef _DEV_READER_H
 #define _DEV_READER_H
 
-
-#include "config.h"
 #include "transcode.h"
 
 int dvd_init(char *dvd_path, int *arg_title, int verb);
