@@ -9,7 +9,7 @@
  *
  *  Multiple track support by Yuqing Deng <deng@tinker.chem.brown.edu>
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,14 +30,8 @@
 #undef DDBUG
 //#define DDBUG
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <unistd.h>
-#include <string.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <sys/stat.h>
+#include "transcode.h"
+
 #include <sys/mman.h>
 #include <limits.h>
 
@@ -45,14 +39,11 @@
 #include "ioaux.h"
 #include "aux_pes.h"
 #include "tc.h"
-#include "transcode.h"
 
 #define BUFFER_SIZE 262144
 static uint8_t *buffer = NULL;
 static FILE *in_file, *out_file;
 
-static int verbose;
-
 static unsigned int track_code=0, vdr_work_around=0;
 
 static int get_pts=0;
@@ -237,7 +228,7 @@ static void pes_ac3_loop (void)
 		subtitle_header.payload_length=tmp2-tmp1;
 		
 		if(verbose & TC_STATS) 
-		  fprintf(stderr,"subtitle=0x%x size=%4d lpts=%d rpts=%f rptsfromvid=%f\n", track_code, tmp2-tmp1, subtitle_header.lpts, subtitle_header.rpts,abs_rpts); 
+		  fprintf(stderr,"subtitle=0x%x size=%4d lpts=%d rpts=%f rptsfromvid=%f\n", track_code, subtitle_header.payload_length, subtitle_header.lpts, subtitle_header.rpts,abs_rpts); 
 		
 		if(p_write(STDOUT_FILENO, (char*) subtitle_header_str, strlen(subtitle_header_str))<0) {
 		  fprintf(stderr, "error writing subtitle\n");
@@ -324,6 +315,8 @@ int ac3scan(int infd, int outfd)
   
   uint16_t sync_word = 0;
 
+  ssize_t bytes_read;
+
   if (!buffer) {
     fprintf(stderr, "%s:%d no memory\n", __FILE__, __LINE__);
     return 1;
@@ -336,11 +329,14 @@ int ac3scan(int infd, int outfd)
     k=0;
     
     for(;;) {
-      
-      if (p_read(infd, &buffer[s], 1) !=1) {
+      bytes_read = p_read(infd, &buffer[s], 1);
+      if (bytes_read <= 0) {
 	//ac3 sync frame scan failed
 	free (buffer);
-	return(ERROR_INVALID_HEADER);
+	if (bytes_read == 0)  /* EOF */
+	  return(0);
+	else
+	  return(ERROR_INVALID_HEADER);
       }
       
       sync_word = (sync_word << 8) + (uint8_t) buffer[s]; 
@@ -410,7 +406,7 @@ int ac3scan(int infd, int outfd)
   }
   
   free (buffer);
-  return(1);
+  return(0);
 }
 
 
