@@ -1,9 +1,9 @@
 /*
- *  decode_lzo.c
+ *  extract_lzo.c
  *
  *  Copyright (C) Tilmann Bitterberg - 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,6 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-
 #include "transcode.h"
 #include "ioaux.h"
 #include "avilib.h"
@@ -41,8 +32,6 @@
 #  include <lzoutil.h>
 #endif
 
-#define MOD_NAME    "decode_lzo"
-
 #define BUFFER_SIZE SIZE_RGB_FRAME<<1
 
 inline static void long2str(long a, unsigned char *b)
@@ -126,7 +115,9 @@ void extract_lzo(info_t *ipipe)
 	      __FILE__, filetype(TC_MAGIC_RAW));
     
     
-    error=p_readwrite(ipipe->fd_in, ipipe->fd_out);
+    error = p_readwrite(ipipe->fd_in, ipipe->fd_out);
+    if (error < 0)
+        error = 1;
     
     break;
   }
