@@ -4,7 +4,7 @@
  *  Copyright (C) Thomas streich - June 2001
  *  Copyright (C) 1999-2001 Aaron Holtzman <aholtzma@ess.engr.uvic.ca>
  *
- *  This file is part of transcode, a linux video stream  processing tool
+ *  This file is part of transcode, a video stream  processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,13 +22,6 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-#include <inttypes.h>
-#include <unistd.h> 
-
 #include "transcode.h"
 #include "ioaux.h"
 #include "avilib.h"
@@ -38,7 +31,6 @@
 static uint8_t buffer[BUFFER_SIZE];
 static FILE *in_file, *out_file;
 
-int verbose;
 
 static void ps_loop (void)
 {
