@@ -9,13 +9,7 @@
   or visit http://www.gnu.org/copyleft/gpl.html
 */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
-#ifdef HAVE_ERRNO_H
-# include <errno.h>
-#endif
+#include "transcode.h"
 
 #ifndef SYS_BSD
 # ifdef HAVE_MALLOC_H
@@ -23,14 +17,9 @@
 # endif
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/stat.h>
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#include <unistd.h>
-
-#include "transcode.h"
+#endif
 
 #include "ioaux.h"
 #include "tc.h"
@@ -45,7 +34,7 @@ unsigned char *xtext = NULL;
 int no[3];
 int      xraw = 0;
 
-int verbose = 0;
+static int verbose_flag = TC_QUIET;
 
 #if (HAVE_OGG && HAVE_VORBIS) 
 
@@ -135,7 +124,7 @@ void flush_pages(stream_t *stream, ogg_packet *op) {
   while (ogg_stream_flush(&stream->outstate, &page)) {
     ih = write(stream->fd, page.header, page.header_len);
     ib = write(stream->fd, page.body, page.body_len);
-    if (verbose > 1)
+    if (verbose_flag & TC_DEBUG)
       fprintf(stderr, "(%s) x/a%d: %d + %d written\n", __FILE__, stream->sno,
               ih, ib);
   }
@@ -148,7 +137,7 @@ void write_pages(stream_t *stream, ogg_packet *op) {
   while (ogg_stream_pageout(&stream->outstate, &page)) {
     ih = write(stream->fd, page.header, page.header_len);
     ib = write(stream->fd, page.body, page.body_len);
-    if (verbose > 1)
+    if (verbose_flag & TC_DEBUG)
       fprintf(stderr, "(%s) x/a%d: %d + %d written\n", __FILE__, stream->sno,
               ih, ib);
   }
@@ -201,7 +190,7 @@ void handle_packet(stream_t *stream, ogg_packet *pack, ogg_page *page) {
         return;
       i = write(stream->fd, (char *)&pack->packet[hdrlen + 1],
 	  pack->bytes - 1 - hdrlen);
-      if (verbose > 1)
+      if (verbose_flag & TC_DEBUG)
         fprintf(stderr, "(%s) x/v%d: %d written\n", __FILE__, stream->sno, i);
       break;
     case 't':
@@ -212,7 +201,7 @@ void handle_packet(stream_t *stream, ogg_packet *pack, ogg_page *page) {
       if (xraw) {
         i = write(stream->fd, (char *)&pack->packet[hdrlen + 1],
                   pack->bytes - 1 - hdrlen);
-        if (verbose > 1)
+        if (verbose_flag & TC_DEBUG)
           fprintf(stderr, "(%s) x/t%d: %d written\n", __FILE__,
                   stream->sno, i);
         return;
@@ -222,7 +211,7 @@ void handle_packet(stream_t *stream, ogg_packet *pack, ogg_page *page) {
       if ((strlen(sub) > 1) || (*sub != ' ')) {
         sst = (pack->granulepos / stream->sample_rate) * 1000;
         pgp = sst + lenbytes;
-        sprintf(out, "%d\r\n%02d:%02d:%02d,%03d --> " \
+        snprintf(out,sizeof(out), "%d\r\n%02d:%02d:%02d,%03d --> " \
                 "%02d:%02d:%02d,%03d\r\n", stream->subnr + 1,
                 (int)(sst / 3600000),
                 (int)(sst / 60000) % 60,
@@ -241,7 +230,7 @@ void handle_packet(stream_t *stream, ogg_packet *pack, ogg_page *page) {
         i += write(stream->fd, sub, strlen(sub));
         i += write(stream->fd, "\r\n\r\n", 4);
         stream->subnr++;
-        if (verbose > 1)
+        if (verbose_flag & TC_DEBUG)
           fprintf(stderr, "(%s) x/t%d: %d written\n", __FILE__,
                   stream->sno, i);
       }
@@ -255,7 +244,7 @@ void handle_packet(stream_t *stream, ogg_packet *pack, ogg_page *page) {
             else
               i = write(stream->fd, (char *)&pack->packet[1],
                         pack->bytes - 1);
-            if (verbose > 1)
+            if (verbose_flag & TC_DEBUG)
               fprintf(stderr, "(%s) x/a%d: %d written\n", __FILE__,
                       stream->sno, i);
             return;
@@ -279,7 +268,7 @@ void handle_packet(stream_t *stream, ogg_packet *pack, ogg_page *page) {
           i = write(stream->fd, pack->packet + 1 + hdrlen,
                     pack->bytes - 1 - hdrlen);
           stream->bwritten += i;
-          if (verbose > 1)
+          if (verbose_flag & TC_DEBUG)
             fprintf(stderr, "(%s) x/a%d: %d written\n", __FILE__,
                     stream->sno, i);
           break;
@@ -314,7 +303,7 @@ void process_ogm(int fdin, int fdout)
         return;
       }
       if ((nread = read(fdin, buf, BLOCK_SIZE)) <= 0) {
-        if (verbose > 0)
+        if (verbose_flag & TC_INFO)
           fprintf(stderr, "(%s) end of stream 1\n", __FILE__);
         return;
       }
@@ -343,7 +332,7 @@ void process_ogm(int fdin, int fdout)
         }
 
         memset(stream, 0, sizeof(stream_t));
-        if (verbose > 0) {
+        if (verbose_flag & TC_INFO) {
           vorbis_info_init(&vi);
           vorbis_comment_init(&vc);
           if (vorbis_synthesis_headerin(&vi, &vc, &pack) >= 0) {
@@ -371,7 +360,7 @@ void process_ogm(int fdin, int fdout)
           }
           if (!xraw)
             ogg_stream_init(&stream->outstate, rand());
-          if (verbose > 0)
+          if (verbose_flag & TC_INFO)
             fprintf(stderr, "(%s) Extracting a%d to \"%s\".\n", __FILE__,
                     nastreams + 1, "new_name");
           do
@@ -392,7 +381,7 @@ void process_ogm(int fdin, int fdout)
           fprintf(stderr, "(%s) (a%d/%d) Found old audio header. Not " \
                   "supported.\n", __FILE__, nastreams + 1, numstreams + 1);
         } else {
-          if (verbose > 0)
+          if (verbose_flag & TC_INFO)
             fprintf(stderr, "(%s) OGG stream %d has an old header with an " \
                     "unknown type.", __FILE__, numstreams + 1);
         }
@@ -406,7 +395,7 @@ void process_ogm(int fdin, int fdout)
           ccodec[4] = 0;
           codec = (sth->subtype[0] << 24) + 
             (sth->subtype[1] << 16) + (sth->subtype[2] << 8) + sth->subtype[3]; 
-          if (verbose > 0)
+          if (verbose_flag & TC_INFO)
             fprintf(stderr, "(%s) (v%d/%d) fps: %.3f width height: %dx%d " \
                     "codec: %p (%s)\n", __FILE__, nvstreams + 1,
                     numstreams + 1,
@@ -426,7 +415,7 @@ void process_ogm(int fdin, int fdout)
           if (extraction_requested(xvideo, nvstreams + 1, NOVIDEO)) {
 	    stream->fd = fdout;
             
-            if (verbose > 0)
+            if (verbose_flag & TC_INFO)
               fprintf(stderr, "(%s) Extracting v%d to \"%s\".\n", __FILE__,
                       nvstreams + 1, "new_name");
             do {
@@ -442,7 +431,7 @@ void process_ogm(int fdin, int fdout)
           tc_memcpy(buf, sth->subtype, 4);
           buf[4] = 0;
           codec = strtoul(buf, NULL, 16);
-          if (verbose > 0) {
+          if (verbose_flag & TC_INFO) {
             fprintf(stderr, "(%s) (a%d/%d) codec: %d (0x%04x) (%s), bits per " \
                     "sample: %d channels: %hd  samples per second: %lld",
                     __FILE__, nastreams + 1, numstreams + 1, codec, codec,
@@ -474,7 +463,7 @@ void process_ogm(int fdin, int fdout)
                       codec == ACAC3 ? "ac3" : "audio");
 		      */
             stream->fd = fdout;
-            if (verbose > 0)
+            if (verbose_flag & TC_INFO)
               fprintf(stderr, "(%s) Extracting a%d to \"%s\".\n", __FILE__,
                       nastreams + 1, "new_name");
             do {
@@ -485,7 +474,7 @@ void process_ogm(int fdin, int fdout)
           nastreams++;
           numstreams++;
         } else if (!strncmp(sth->streamtype, "text", 4)) {
-          if (verbose > 0)
+          if (verbose_flag & TC_INFO)
             fprintf(stderr, "(%s) (t%d/%d) text/subtitle stream\n", __FILE__,
                     ntstreams + 1, numstreams + 1);
           stream = (stream_t *)malloc(sizeof(stream_t));
@@ -502,13 +491,13 @@ void process_ogm(int fdin, int fdout)
             new_name = malloc(strlen(basename) + 20);
             if (!new_name) {
               fprintf(stderr, "(%s) Failed to allocate %d bytes.\n", __FILE__,
-                (int)strlen(basename) + 10);
+                (int)strlen(basename) + 20);
               exit(1);
             }
             if (!xraw)
-              sprintf(new_name, "%s-t%d.srt", basename, ntstreams + 1);
+              snprintf(new_name, strlen(basename) + 20, "%s-t%d.srt", basename, ntstreams + 1);
             else
-              sprintf(new_name, "%s-t%d.raw", basename, ntstreams + 1);
+              snprintf(new_name, strlen(basename) + 20, "%s-t%d.raw", basename, ntstreams + 1);
             //stream->fd = open(new_name, O_WRONLY | O_CREAT | O_TRUNC,
             //                S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
             stream->fd = fdout;
@@ -517,7 +506,7 @@ void process_ogm(int fdin, int fdout)
                       __FILE__, new_name, errno, strerror(errno));
               exit(1);
             }
-            if (verbose > 0)
+            if (verbose_flag & TC_INFO)
               fprintf(stderr, "(%s) Extracting t%d to \"%s\".\n", __FILE__,
                       ntstreams + 1, new_name);
             do
@@ -544,11 +533,11 @@ void process_ogm(int fdin, int fdout)
     sno = ogg_page_serialno(&page);
     stream = find_stream(sno);
     if (stream == NULL) {
-      if (verbose > 1)
+      if (verbose_flag & TC_DEBUG)
         fprintf(stderr, "(%s) Encountered packet for an unknown serial " \
                 "%d !?\n", __FILE__, sno);
     } else {
-      if (verbose > 1)
+      if (verbose_flag & TC_DEBUG)
         fprintf(stderr, "(%s) %c%d: NEW PAGE\n",
                 __FILE__, stream->stype, stream->sno);
                 
@@ -595,7 +584,7 @@ void process_ogm(int fdin, int fdout)
           }
           stream = stream->next;
         }
-        if (verbose > 0)
+        if (verbose_flag & TC_INFO)
           fprintf(stderr, "(%s) end of stream\n", __FILE__);
         endofstream = 1;
         break;
@@ -618,7 +607,7 @@ void extract_ogm (info_t *ipipe)
   xvideo = malloc (16); xaudio = malloc (16); xtext = malloc (16);
   memset (xvideo, 0, 16); memset (xaudio, 0, 16); memset (xtext, 0, 16);
 
-  verbose = ipipe->verbose;
+  verbose_flag = ipipe->verbose;
 
   if (ipipe->select == TC_VIDEO) {
 
