@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,11 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
+#include "transcode.h"
+
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#include <unistd.h>
-#include <string.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <sys/stat.h>
+#endif
 #include <sys/mman.h>
 
 #include "ioaux.h"
@@ -38,15 +34,13 @@
 #define MAX_BUF 4096
 char audio[MAX_BUF];
 
-
 #define BUFFER_SIZE 262144
 static uint8_t buffer[BUFFER_SIZE];
 static FILE *in_file, *out_file;
 
-static int verbose;
-
 static unsigned int track_code;
 
+
 static void pes_lpcm_loop (void)
 {
     static int mpeg1_skip_table[16] = {
