@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,22 +21,23 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#include <string.h>
-#include <time.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
+#define MOD_NAME    "import_im.so"
+#define MOD_VERSION "v0.0.4 (2003-09-15)"
+#define MOD_CODEC   "(video) RGB"
 
 #include "transcode.h"
 
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_RGB | TC_CAP_VID;
+
+#define MOD_PRE im
+#include "import_def.h"
+
+#include <time.h>
+#include <sys/types.h>
 #include <regex.h>
 
-// transcode defines this as well as ImageMagick.
+/* transcode defines these as well as ImageMagick. */
 #undef PACKAGE_NAME
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
@@ -45,18 +46,7 @@
 #include <magick/api.h>
 
 
-#define MOD_NAME    "import_im.so"
-#define MOD_VERSION "v0.0.4 (2003-09-15)"
-#define MOD_CODEC   "(video) RGB"
-
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_VID;
-
-#define MOD_PRE im
-#include "import_def.h"
-
-#define MAX_BUF 1024
-char import_cmd_buf[MAX_BUF];
+extern int errno;
 
 char
     *head = NULL,
@@ -67,7 +57,7 @@ int
     last_frame = 0,
     current_frame = 0,
     pad = 0;
- 
+
   
 /* ------------------------------------------------------------ 
  *
@@ -78,7 +68,11 @@ int
 MOD_open
 {
   int
-    result;
+    result,
+    string_length;
+
+  long
+    sret;
 
   char
       *regex,
@@ -95,9 +89,9 @@ MOD_open
       pmatch[4];
 
   if(param->flag == TC_AUDIO) {
-      return(0);
+      return(TC_IMPORT_OK);
   }
-  
+
   if(param->flag == TC_VIDEO) {
 
     param->fd = NULL;
@@ -113,8 +107,12 @@ MOD_open
     result = regexec(&preg, vob->video_in_file, 4, pmatch, 0);
     if (result) {
         fprintf(stderr, "Regex match failed: no image sequence\n");
-        head = malloc(strlen(vob->video_in_file) + 1);
-	head = strcpy(head, vob->video_in_file);
+	string_length = strlen(vob->video_in_file) + 1;
+        if ((head = malloc(string_length)) == NULL) {
+	    perror("filename head");
+	    return(TC_IMPORT_ERROR);
+	}
+	strlcpy(head, vob->video_in_file, string_length);
         tail = malloc(1);
         tail[0] = 0;
         first_frame = -1;
@@ -122,17 +120,19 @@ MOD_open
     }
     else {
         // split the name into head, frame number, and tail
-        head = malloc(pmatch[1].rm_eo - pmatch[1].rm_so + 1);
-        head = strncpy(head, 
-                       vob->video_in_file, 
-                       pmatch[1].rm_eo - pmatch[1].rm_so);
-        head[pmatch[1].rm_eo - pmatch[1].rm_so] = '\0';
+        string_length = pmatch[1].rm_eo - pmatch[1].rm_so + 1;
+        if ((head = malloc(string_length)) == NULL) {
+            perror("filename head");
+            return(TC_IMPORT_ERROR);
+        }
+        strlcpy(head, vob->video_in_file, string_length);
 
-        frame = malloc(pmatch[2].rm_eo - pmatch[2].rm_so + 1);
-        frame = strncpy(frame, 
-                        vob->video_in_file + pmatch[2].rm_so, 
-                        pmatch[2].rm_eo - pmatch[2].rm_so);
-        frame[pmatch[2].rm_eo - pmatch[2].rm_so] = '\0';
+        string_length = pmatch[2].rm_eo - pmatch[2].rm_so + 1;
+        if ((frame = malloc(string_length)) == NULL) {
+            perror("filename frame");
+            return(TC_IMPORT_ERROR);
+        }
+        strlcpy(frame, vob->video_in_file + pmatch[2].rm_so, string_length);
 
         // If the frame number is padded with zeros, record how many digits 
         // are actually being used.
@@ -141,20 +141,26 @@ MOD_open
         }
         first_frame = atoi(frame);
 
-        tail = malloc(pmatch[3].rm_eo - pmatch[3].rm_so + 1);
-        tail = strncpy(tail, 
-               vob->video_in_file + pmatch[3].rm_so, 
-               pmatch[3].rm_eo - pmatch[3].rm_so);
-        tail[pmatch[3].rm_eo - pmatch[3].rm_so] = '\0';
+        string_length = pmatch[3].rm_eo - pmatch[3].rm_so + 1;
+        if ((tail = malloc(string_length)) == NULL) {
+            perror("filename tail");
+            return(TC_IMPORT_ERROR);
+        }
+        strlcpy(tail, vob->video_in_file + pmatch[3].rm_so, string_length);
 
         // find the last frame by trying to open files
         last_frame = first_frame; 
         filename = malloc(strlen(head) + pad + strlen(tail) + 1);
-        frame = malloc(pad + 1);
+        /* why remalloc frame? */
+        /* frame = malloc(pad + 1); */
         do {
             last_frame++;
-            sprintf(printfspec, "%%s%%0%dd%%s", pad);
-            sprintf(filename, printfspec, head, last_frame, tail);
+            snprintf(printfspec, sizeof(printfspec), "%%s%%0%dd%%s", pad);
+            string_length = strlen(head) + pad + strlen(tail) + 1;
+            sret = snprintf(filename, string_length, printfspec, head,
+                                                      last_frame, tail);
+            if (tc_test_string(__FILE__, __LINE__, string_length, sret, errno))
+              return(TC_IMPORT_ERROR);
         } while (close(open(filename, O_RDONLY)) != -1); 
         last_frame--;
         free(filename);
@@ -166,9 +172,9 @@ MOD_open
     // initialize ImageMagick
     InitializeMagick("");
 
-    return(0);
+    return(TC_IMPORT_OK);
   }
- 
+
   return(TC_IMPORT_ERROR);
 }
 
@@ -200,37 +206,40 @@ MOD_decode {
 
     int
         column,
-        row;
+        row,
+        string_length;
 
 
     if (current_frame > last_frame)
         return(TC_IMPORT_ERROR);
 
     // build the filename for the current frame
-    filename = malloc(strlen(head) + pad + strlen(tail) + 1);
+    string_length = strlen(head) + pad + strlen(tail) + 1;
+    filename = malloc(string_length);
     if (pad) {
         frame = malloc(pad+1);
         framespec = malloc(10);
-        sprintf(framespec, "%%0%dd", pad);
-        sprintf(frame, framespec, current_frame);
+        snprintf(framespec, 10, "%%0%dd", pad);
+        snprintf(frame, pad+1, framespec, current_frame);
+        free(framespec);
         frame[pad] = '\0';
     }
     else if (first_frame >= 0) {
         frame = malloc(10);
-        sprintf(frame, "%d", current_frame);
+        snprintf(frame, 10, "%d", current_frame);
     }
-    strcpy(filename, head);
+    strlcpy(filename, head, string_length);
     if (frame != NULL) {
-        strcpy(filename + strlen(head), frame);
-        strcpy(filename + strlen(head) + strlen(frame), tail);
+        strlcat(filename, frame, string_length);
+        free(frame);
+        frame = NULL;
     }
-    else
-        strcpy(filename + strlen(head), tail);
+    strlcat(filename, tail, string_length);
 
     // Have ImageMagick open the file and read in the image data.
     GetExceptionInfo(&exception_info);
     image_info=CloneImageInfo((ImageInfo *) NULL);
-    (void) strcpy(image_info->filename, filename);
+    (void) strlcpy(image_info->filename, filename, MaxTextExtent);
     image=ReadImage(image_info,&exception_info);
     if (image == (Image *) NULL) {
         MagickError(exception_info.severity,
@@ -256,11 +265,14 @@ MOD_decode {
            * the low and high byte.
            */
           param->buffer[(row * image->columns + column) * 3 + 0] =
-               (char) (pixel_packet[(image->rows - row - 1) * image->columns + column].blue >> 8);
+               (char) (pixel_packet[(image->rows - row - 1) * image->columns +
+                                                            column].blue >> 8);
           param->buffer[(row * image->columns + column) * 3 + 1] =
-               (char) (pixel_packet[(image->rows - row - 1) * image->columns + column].green >> 8);
+               (char) (pixel_packet[(image->rows - row - 1) * image->columns +
+                                                           column].green >> 8);
           param->buffer[(row * image->columns + column) * 3 + 2] =
-               (char) (pixel_packet[(image->rows - row - 1) * image->columns + column].red >> 8);
+               (char) (pixel_packet[(image->rows - row - 1) * image->columns +
+                                                             column].red >> 8);
         }
     }
 
@@ -276,9 +288,8 @@ MOD_decode {
     DestroyImageInfo(image_info);
     DestroyExceptionInfo(&exception_info);
     free(filename);
-    free(frame);
 
-    return(0);
+    return(TC_IMPORT_OK);
 }
 
 /* ------------------------------------------------------------ 
@@ -295,7 +306,7 @@ MOD_close
 
   DestroyMagick();
 
-  return(0);
+  return(TC_IMPORT_OK);
 }
 
 
