@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - February 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,19 +21,19 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#include <string.h>
-#include <time.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
+#define MOD_NAME    "import_imlist.so"
+#define MOD_VERSION "v0.0.2 (2003-11-13)"
+#define MOD_CODEC   "(video) RGB"
 
 #include "transcode.h"
 
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_RGB | TC_CAP_VID | TC_CAP_AUD;
+
+#define MOD_PRE imlist
+#include "import_def.h"
+
+
 // transcode defines this as well as ImageMagick.
 #undef PACKAGE_NAME
 #undef PACKAGE_TARNAME
@@ -42,18 +42,6 @@
 
 #include <magick/api.h>
 
-#define MOD_NAME    "import_imlist.so"
-#define MOD_VERSION "v0.0.2 (2003-11-13)"
-#define MOD_CODEC   "(video) RGB"
-
-#define MOD_PRE im
-#include "import_def.h"
-
-#define MAX_BUF 1024
-char import_cmd_buf[MAX_BUF];
-
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_VID|TC_CAP_AUD;
 
 int
     first_frame = 0,
@@ -64,6 +52,7 @@ int
 static FILE *fd; 
 static char buffer[PATH_MAX+2];
   
+
 /* ------------------------------------------------------------ 
  *
  * open stream
@@ -73,7 +62,7 @@ static char buffer[PATH_MAX+2];
 MOD_open
 {
   if(param->flag == TC_AUDIO) {
-      return(0);
+      return(TC_IMPORT_OK);
   }
   
   if(param->flag == TC_VIDEO) {
@@ -85,7 +74,7 @@ MOD_open
     // initialize ImageMagick
     InitializeMagick("");
 
-    return(0);
+    return(TC_IMPORT_OK);
   }
  
   return(TC_IMPORT_ERROR);
@@ -100,7 +89,6 @@ MOD_open
 
 MOD_decode {
 
-
     ExceptionInfo
         exception_info;
 
@@ -120,7 +108,7 @@ MOD_decode {
         column,
         row, n;
 
-    if(param->flag == TC_AUDIO) return(0);
+    if(param->flag == TC_AUDIO) return(TC_IMPORT_OK);
     
     // read a filename from the list
     if(fgets (buffer, PATH_MAX, fd)==NULL) return(TC_IMPORT_ERROR);    
@@ -134,13 +122,14 @@ MOD_decode {
     // Have ImageMagick open the file and read in the image data.
     GetExceptionInfo(&exception_info);
     image_info=CloneImageInfo((ImageInfo *) NULL);
-    (void) strcpy(image_info->filename, filename);
+    (void) strlcpy(image_info->filename, filename, MaxTextExtent);
 
     image=ReadImage(image_info, &exception_info);
     if (image == (Image *) NULL) {
-        MagickError(exception_info.severity,exception_info.reason,exception_info.description);
+        MagickError(exception_info.severity, exception_info.reason,
+                    exception_info.description);
 	// skipping
-	return 0;
+	return TC_IMPORT_OK;
     }
 
     /*
@@ -150,11 +139,14 @@ MOD_decode {
     for (row = 0; row < image->rows; row++) {
         for (column = 0; column < image->columns; column++) {
           param->buffer[(row * image->columns + column) * 3 + 0] =
-               pixel_packet[(image->rows - row - 1) * image->columns + column].blue;
+               pixel_packet[(image->rows - row - 1) * image->columns +
+                                                                 column].blue;
           param->buffer[(row * image->columns + column) * 3 + 1] =
-               pixel_packet[(image->rows - row - 1) * image->columns + column].green;
+               pixel_packet[(image->rows - row - 1) * image->columns +
+                                                                 column].green;
           param->buffer[(row * image->columns + column) * 3 + 2] =
-               pixel_packet[(image->rows - row - 1) * image->columns + column].red;
+               pixel_packet[(image->rows - row - 1) * image->columns +
+                                                                 column].red;
         }
     }
 
@@ -167,7 +159,7 @@ MOD_decode {
     DestroyImageInfo(image_info);
     DestroyExceptionInfo(&exception_info);
 
-    return(0);
+    return(TC_IMPORT_OK);
 }
 
 /* ------------------------------------------------------------ 
@@ -186,13 +178,10 @@ MOD_close
     // This is very necessary
     DestroyMagick();
 
-    
-    return(0);
+    return(TC_IMPORT_OK);
   }
   
-  if(param->flag == TC_AUDIO) return(0);
+  if(param->flag == TC_AUDIO) return(TC_IMPORT_OK);
  
   return(TC_IMPORT_ERROR);
 }
-
-
