@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,24 +21,18 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#include "transcode.h"
-
 #define MOD_NAME    "import_null.so"
 #define MOD_VERSION "v0.2.0 (2002-01-19)"
 #define MOD_CODEC   "(video) null | (audio) null"
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=-1;
+#include "transcode.h"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = -1;
 
 #define MOD_PRE null
 #include "import_def.h"
 
-#define MAX_BUF 1024
-char import_cmd_buf[MAX_BUF];
 
 /* ------------------------------------------------------------ 
  *
