@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Tilmann Bitterberg - May 2002
  *
- *  This file is part of transcode, a linux video stream  processing tool
+ *  This file is part of transcode, a video stream  processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,27 +21,21 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-
-#include "transcode.h"
-
 #define MOD_NAME    "import_nvrec.so"
 #define MOD_VERSION "v0.1.4 (2002-10-17)"
 #define MOD_CODEC   "(video) nvrec | (audio) nvrec"
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_YUV|TC_CAP_PCM;
+#include "transcode.h"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_YUV | TC_CAP_PCM;
 
 #define MOD_PRE nvrec
 #include "import_def.h"
 
+#include <sys/types.h>
+
+
 #define MAX_DISPLAY_PTS 25
 
 #define MAX_BUF 1024
@@ -72,21 +66,21 @@ MOD_open
   }
 
   if (vob->out_flag) {
-      strncpy(afile, vob->audio_out_file, strlen(vob->audio_out_file));
+      strlcpy(afile, vob->audio_out_file, sizeof(afile));
       vob->out_flag = 0;  /* XXX */
   } else
-      strcpy(afile, "audio.avi");
+      strlcpy(afile, "audio.avi", sizeof(afile));
 
-  strcpy(prgname, "DIVX4rec");
+  strlcpy(prgname, "DIVX4rec", sizeof(prgname));
 
   /* this is ugly */
   ret = system("DIVX4rec -h >/dev/null 2>&1");
   if (ret == 0 || ret == 65280)
-      strcpy(prgname, "DIVX4rec");
+      strlcpy(prgname, "DIVX4rec", sizeof(prgname));
 
   ret = system("divx4rec -h >/dev/null 2>&1");
   if (ret == 0 || ret == 65280)
-      strcpy(prgname, "divx4rec");
+      strlcpy(prgname, "divx4rec", sizeof(prgname));
 
   /* make this even more ugly. Add another check for prgname */
   if (tc_test_program(prgname) != 0) return (TC_EXPORT_ERROR);
@@ -123,7 +117,7 @@ MOD_open
 
     /* Check NVrec features */
     memset (buffer, 0, 1024);
-    sprintf (buffer, "%s -h 2>&1", prgname);
+    snprintf (buffer, sizeof(buffer), "%s -h 2>&1", prgname);
     f = popen (buffer, "r");
     memset (buffer, 0, 1024);
 
