@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - July 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,23 +21,21 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#include "transcode.h"
-#include "magic.h"
-
 #define MOD_NAME    "import_ogg.so"
 #define MOD_VERSION "v0.0.2 (2003-08-21)"
 #define MOD_CODEC   "(video) all | (audio) Ogg Vorbis"
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AUD|TC_CAP_PCM|TC_CAP_VID;
+#include "transcode.h"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_RGB | TC_CAP_YUV | TC_CAP_AUD | TC_CAP_PCM | TC_CAP_VID;
 
 #define MOD_PRE ogg
 #include "import_def.h"
 
+#include "magic.h"
+
+
 #define MAX_BUF 1024
 char import_cmd_buf[MAX_BUF];
 
