@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Marzio Malanchini - March 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,18 +21,14 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#include "transcode.h"
-
 #define MOD_NAME    "import_xml.so"
 #define MOD_VERSION "v0.0.8 (2003-07-09)"
 #define MOD_CODEC   "(video) * | (audio) *"
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=-1;
+#include "transcode.h"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = -1;
 
 #define MOD_PRE xml
 #include "import_def.h"
