@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,23 +21,19 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-
-#include "transcode.h"
-
 #define MOD_NAME    "import_yuv4mpeg.so"
 #define MOD_VERSION "v0.2.4 (2002-01-20)"
 #define MOD_CODEC   "(video) YUV4MPEGx | (audio) WAVE"
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_PCM;
+#include "transcode.h"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_RGB | TC_CAP_YUV | TC_CAP_PCM;
 
 #define MOD_PRE yuv4mpeg
 #include "import_def.h"
 
+
 #define MAX_BUF 1024
 char import_cmd_buf[MAX_BUF];
 
