@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream  processing tool
+ *  This file is part of transcode, a video stream  processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,67 +26,81 @@
 #include <xio.h>
 
 #define MAX_BUF 4096
-static char buffer[MAX_BUF];
-char filename[1024];
+static uint8_t buffer[MAX_BUF];  /* only used in p_readwrite() */
 
-ssize_t p_read(int fd, char *buf, size_t len)
+extern int errno;
+
+
+ssize_t p_read(int fd, uint8_t *buf, size_t len)
 {
    ssize_t n = 0;
    ssize_t r = 0;
 
    while (r < len) {
-      n = xio_read (fd, buf + r, len - r);
 
-	  if (n == 0)
-		break;
-	  if (n < 0) {
-		if (errno == EINTR)
-		  continue;
-		else
-		  break;
-	  } 
-      r += n;
-   }
+      n = xio_read(fd, buf + r, len - r);
 
-   return r;
-}
-
-ssize_t p_write (int fd, char *buf, size_t len)
-{
-   ssize_t n = 0;
-   ssize_t r = 0;
-
-   while (r < len) {
-      n = xio_write (fd, buf + r, len - r);
+      if (n == 0)  /* EOF */
+          break;
       if (n < 0) {
-		if (errno == EINTR)
-		  continue;
-		else
-		  break;
-	  }
+          if (errno == EINTR)
+              continue;
+          else
+              break;
+      }
+
       r += n;
    }
    return r;
 }
 
+
+ssize_t p_write(int fd, uint8_t *buf, size_t len)
+{
+   ssize_t n = 0;
+   ssize_t r = 0;
+
+   while (r < len) {
+
+      n = xio_write(fd, buf + r, len - r);
+
+      if (n < 0) {
+          if (errno == EINTR)
+              continue;
+          else
+              break;
+      }
+
+      r += n;
+   }
+   return r;
+}
+
+
 int p_readwrite(int fd_in, int fd_out)
 {
     ssize_t bytes;
-    int error=0;
+    int error = 0;
 
     do {
-	
-	bytes=p_read(fd_in, buffer, MAX_BUF);
 
-	// error on read?
-	if(bytes<0) return(-1);
-	
-	// read stream end?
-	if(bytes!=MAX_BUF) error=1;
-	
-	// write stream problems?
-	if(p_write(fd_out, buffer, bytes)!= bytes) error=1;
-    } while(!error);
+	bytes = p_read(fd_in, buffer, MAX_BUF);
+
+	/* error on read? */
+	if (bytes < 0)
+            return(-1);
+
+	/* read stream end? */
+	if (bytes != MAX_BUF)
+            error = 1;
+
+        if (bytes) {
+            /* write stream problems? */
+            if (p_write(fd_out, buffer, bytes) != bytes)
+                error = 1;
+        }
+
+    } while (!error);
  
     return(0);
 }
@@ -94,11 +108,11 @@ int p_readwrite(int fd_in, int fd_out)
 
 int file_check(char *file)
 {
-    // checks for sane file
+    /* checks for sane file */
 
     struct stat fbuf;
-    
-    if(xio_stat(file, &fbuf) || file==NULL){
+
+    if (xio_stat(file, &fbuf) || file == NULL) {
 	fprintf(stderr, "(%s) invalid file \"%s\"\n", __FILE__, file);
 	return(1);
     }
@@ -106,16 +120,18 @@ int file_check(char *file)
     return(0);
 }
 
+
 void version(char *exe)
 {
-    // print id string to stderr
-    fprintf(stderr, "%s (%s v%s) (C) 2001-2003 Thomas Oestreich\n", exe, PACKAGE, VERSION);
+    /* print id string to stderr */
+    fprintf(stderr, "%s (%s v%s) (C) 2001-2003 Thomas Oestreich\n",
+                    exe, PACKAGE, VERSION);
 }
 
 
 void import_info(int code, char *EXE) 
 {
-  fprintf(stderr, "[%s] exit code (%d)\n", EXE, code);
+    fprintf(stderr, "[%s] exit code (%d)\n", EXE, code);
 }
 
 
@@ -123,26 +139,28 @@ unsigned int stream_read_int16(unsigned char *s)
 { 
   unsigned int a, b, result;
   
-  a=s[0];
-  b=s[1];
+  a = s[0];
+  b = s[1];
   
-  result = ( a << 8) | b;
+  result = (a << 8) | b;
   return result;
 }
 
+
 unsigned int stream_read_int32(unsigned char *s)
 { 
   unsigned int a, b, c, d, result;
   
-  a=s[0];
-  b=s[1];
-  c=s[2];
-  d=s[3];
+  a = s[0];
+  b = s[1];
+  c = s[2];
+  d = s[3];
   
   result = (a << 24) | (b << 16) | (c << 8) | d;
   return result;
 }
 
+
 double read_time_stamp(unsigned char *s)
 {
   
@@ -229,54 +247,79 @@ int probe_path(char *name)
 
     if(name == NULL) { 
       fprintf(stderr, "(%s) invalid file \"%s\"\n", __FILE__, name);
-      return(-1);
+      return(TC_PROBE_PATH_INVALID);
     }
- 
-    
+
     if(xio_stat(name, &fbuf)==0) {
 
-      //inode exists
-      
-      // treat block device as absolute directory path
-      if(S_ISBLK(fbuf.st_mode) 
-#ifdef SYS_BSD // accessing through the raw device (/dev/rdiskX)
-	      || S_ISCHR(fbuf.st_mode)
-#endif
-	      )
-	   return(2);
+      /* inode exists */
 
-      // char device? v4l?
+      /* treat DVD device as absolute directory path */
+      if (S_ISBLK(fbuf.st_mode))
+	   return(TC_PROBE_PATH_ABSPATH);
+
+      /* char device could be several things, depending on system */
+      /* *BSD DVD device? v4l? bktr? sunau? */
       if(S_ISCHR(fbuf.st_mode)) {
 	  switch (major(fbuf.st_rdev)) {
-	      case 81: // v4l
-	      case 14: // dsp
-		  return(4);
+#ifdef SYS_BSD
+# ifdef __OpenBSD__
+	      case 15: /* rcd */
+		  return(TC_PROBE_PATH_ABSPATH);
+              case 42: /* sunau */
+                  return(TC_PROBE_PATH_SUNAU);
+	      case 49: /* bktr */
+                  return(TC_PROBE_PATH_BKTR);
+# endif
+# ifdef __FreeBSD__
+              case 4: /* acd */
+                  return(TC_PROBE_PATH_ABSPATH);
+              case 229: /* bktr */
+                  return(TC_PROBE_PATH_BKTR);
+              case 0: /* OSS */
+                  return(TC_PROBE_PATH_OSS);
+# endif
+              default: /* libdvdread uses "raw" disk devices here */
+                  return(TC_PROBE_PATH_ABSPATH);
+#else
+	      case 81: /* v4l (Linux) */
+                  return(TC_PROBE_PATH_V4L_VIDEO);
+#ifdef HAVE_V4L
+	      case 14: /* dsp (Linux) */
+                  return(TC_PROBE_PATH_V4L_AUDIO);
+#else
+              case 14: /* OSS */
+                  return(TC_PROBE_PATH_OSS);
+#endif
 	      default:
 		  break;
+#endif
 	  }
       }
 
-      // file or directory?
-      if(!S_ISDIR(fbuf.st_mode)) return(0);
+      /* file or directory? */
+      if (!S_ISDIR(fbuf.st_mode))
+          return(TC_PROBE_PATH_FILE);
 
-      // directory, check for absolute path
-      if(name[0] == '/') return(2);
+      /* directory, check for absolute path */
+      if(name[0] == '/')
+          return(TC_PROBE_PATH_ABSPATH);
 
-      //directory mode
-      return(1);
+      /* directory mode */
+      return(TC_PROBE_PATH_RELDIR);
     
     } else {
 
-#ifdef NET_STREAM      
-      //check for network host
-      
-      if((hp = gethostbyname(name)) != NULL) return(3);
-#endif      
+#ifdef NET_STREAM
+      /* check for network host */
+      if ((hp = gethostbyname(name)) != NULL)
+          return(TC_PROBE_PATH_NET);
+#endif
       fprintf(stderr, "(%s) invalid filename or host \"%s\"\n", __FILE__, name);
-      return(-1);
+      return(TC_PROBE_PATH_INVALID);
     }
     
-    return(-1);
+    return(TC_PROBE_PATH_INVALID);
 }
 
 int fps2frc(double _fps)
