@@ -1,12 +1,12 @@
 /*
- *  import_yuv.c
+ *  import_nuv.c
  *
  *  Copyright (C) Thomas streich - June 2001
  *  NUV-code by Andreas Phlsson
  *  bugfix by Christian Vogelgsang <Vogelgsang@informatik.uni-erlangen.de>
  *  more fixes by Tilmann Bitterberg <tilmann@bitterberg.de>  
  *
- *  This file is part of transcode, a linux video stream  processing tool
+ *  This file is part of transcode, a video stream  processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,12 +24,8 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-
 #include "transcode.h"
+
 #include "rtjpeg_vid_plugin.h"
 #include "rtjpeg_aud_plugin.h"
 
