@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,19 +21,12 @@
  *
  */
 
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
-
 #include "transcode.h"
 #include "ioaux.h"
 #include "dvd_reader.h"
 
+#include <sys/errno.h>
+
 int probe_dvd(info_t *ipipe)
 {
 
