@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Alex Stewart - July 2002
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,8 @@
  *
  */
 
-#include <stdio.h>
-
-#include "transcode.h"
 #include "ioaux.h"
+#include "tc.h"
 
 #define LAV_AUDIO_FORMAT TC_CODEC_AC3
 #define LAV_VIDEO_FORMAT TC_CODEC_LAV
