@@ -5,7 +5,7 @@
  *       Based heavily on code by Moritz Bunkus for ogminfo from
  *            http://www.bunkus.org/videotools/ogmtools/index.html
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,20 +23,12 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <unistd.h>
-#include <string.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <sys/stat.h>
+#include "ioaux.h"
+#include "tc.h"
+
 #include <sys/mman.h>
 
-#include "config.h"
-#include "ioaux.h"
-
-#if (HAVE_OGG && HAVE_VORBIS) 
+#if (HAVE_OGG && HAVE_VORBIS)
 
 #include <ogg/ogg.h>
 #include <vorbis/codec.h>
@@ -51,8 +43,6 @@
 #define MAX_VIDEO_TRACKS 255
 #define BLOCK_SIZE 4096
 
-#include "transcode.h"
-
 //#define  OGM_DEBUG
 
 struct demux_t {
@@ -331,11 +321,14 @@ ogg_out:
     //close(fdin);
     return;
 }
-#else
+
+#else   // (HAVE_OGG && HAVE_VORBIS)
+
 void probe_ogg(info_t *ipipe)
 {
     fprintf(stderr, "No support for Ogg/Vorbis compiled in\n");
     ipipe->probe_info->codec=TC_CODEC_UNKNOWN;
     ipipe->probe_info->magic=TC_MAGIC_UNKNOWN;
 }
+
 #endif
