@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,21 +21,13 @@
  *
  */
 
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
-
 #include "transcode.h"
 #include "ioaux.h"
 #include "tc.h"
 #include "aux_pes.h"
 
-static int verbose;
+#include <sys/errno.h>
+
 
 static probe_info_t probe_info;
 void probe_pvn(info_t *ipipe);
@@ -104,6 +96,22 @@ void tcprobe_thread(info_t *ipipe)
         probe_v4l(ipipe);
 	break;
 
+    case TC_MAGIC_BKTR_VIDEO:
+        probe_bktr(ipipe);
+	break;
+
+    case TC_MAGIC_SUNAU_AUDIO:
+        probe_sunau(ipipe);
+	break;
+
+    case TC_MAGIC_BSDAV:
+        probe_bsdav(ipipe);
+	break;
+
+    case TC_MAGIC_OSS_AUDIO:
+        probe_oss(ipipe);
+	break;
+
     case TC_MAGIC_OGG:
 	probe_ogg(ipipe);
 	break;
