@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,16 +21,10 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
-
-#include "config.h"
 #include "transcode.h"
 
+#include <sys/errno.h>
+
 #ifdef HAVE_LIBDV
 #include <libdv/dv.h>
 #endif
@@ -45,25 +39,15 @@ int scan_header_dv(char *buf)
 
     // Initialize DV decoder
 
-#ifdef LIBDV_095    
     if((dv_decoder = dv_decoder_new(TRUE, FALSE, FALSE))==NULL) {
 	fprintf(stderr, "(%s) dv decoder init failed\n", __FILE__);
 	return(-1);
     }
-#else
-    if((dv_decoder = dv_decoder_new())==NULL) {
-	fprintf(stderr, "(%s) dv decoder init failed\n", __FILE__);
-	return(-1);
-    }
-    dv_init();
-#endif
 
     dv_decoder->prev_frame_decoded = 0;
     cc=dv_parse_header(dv_decoder, buf);
 
-#ifdef LIBDV_095    
     dv_decoder_free(dv_decoder);
-#endif
 
 #endif
     return(cc);
