@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,23 +21,20 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "transcode.h"
+
 #include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
 #include <limits.h>
 
-#include "transcode.h"
 #include "ioaux.h"
 #include "tc.h"
-#include <xio.h>
+#include "xio.h"
+
 #define EXE "tcdecode"
 
 extern long fileinfo(int fd, int skip);
 
-static int verbose=TC_QUIET;
+int verbose=TC_QUIET;
 
 void import_exit(int code) 
 {
