@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,24 +21,20 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
-#include <limits.h>
-#include <xio.h>
-#include "config.h"
 #include "transcode.h"
+
+#include <sys/errno.h>
+#include <limits.h>
+#include "xio.h"
 #include "ioaux.h"
 #include "tc.h"
 
+
 #define EXE "tcextract"
 
 #define MAX_BUF 1024
 
-static int verbose=TC_INFO;
+int verbose=TC_INFO;
 
 void import_exit(int code) 
 {
