@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Malanchini Marzio - March 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,21 +21,16 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "transcode.h"
+
+#include <sys/ipc.h>
+#include <sys/shm.h>
 #include <sys/errno.h>
-#include <errno.h>
-#include <unistd.h>
 #include <math.h>
 
-#include "config.h"
-#include "transcode.h"
 #include "ioxml.h"
 #include "ioaux.h"
 #include "magic.h"
-#include <sys/ipc.h>
-#include <sys/shm.h>
 
 #define EXE "tcxmlcheck"
 
