@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Tilmann Bitterberg - September 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,21 +21,11 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#else
-# define PACKAGE "transcode"
-# define VERSION "unknown"
-#endif
-
-#include <stdio.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-
 #include "transcode.h"
 
+#include <ctype.h>
+
+
 /* ParseColor and QueryColorDatabase are from ImageMagick */
 
 static char *ParseColor(char *data)
@@ -228,6 +218,7 @@ int main (int argc, char *argv[])
     char *out = NULL, *d;
     char *outfile = NULL, *infile=NULL;
     color_t *colormap;
+    long sret;
 
     while ((ch = getopt(argc, argv, "i:o:vh?")) != -1) {
 	
@@ -335,11 +326,16 @@ int main (int argc, char *argv[])
 
     for (j=0; j<colors; j++) {
 	p = clist[j];
+
 	keys[j] = malloc(bwidth+1); // a bit stupid since bwidth is usually just 1 or 2
 	keys[j][bwidth]='\0';
 
-	strncpy(keys[j], p, bwidth);
-	strcpy(target,"gray");
+	sret = strlcpy(keys[j], p, bwidth+1);
+	tc_test_string(__FILE__, __LINE__, bwidth+1, sret, errno);
+
+	sret = strlcpy(target, "gray", sizeof(target));
+	tc_test_string(__FILE__, __LINE__, sizeof(target), sret, errno);
+
 	q = ParseColor (p+bwidth);
 	if (q != (char *) NULL)
 	{
