@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - January 2002
  *
- *  This file is part of transcode, a linux video stream  processing tool
+ *  This file is part of transcode, a video stream  processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,16 +24,6 @@
 #ifndef _TC_V4L_VCR_H
 #define _TC_V4L_VCR_H 1
 
-#include <pthread.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/time.h>
-#include <signal.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <fcntl.h>
 #include <sys/ioctl.h>
 
 #include "transcode.h"
