@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,9 +21,6 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include "transcode.h"
 #include "dl_loader.h"
 #include "framebuffer.h"
@@ -137,7 +134,7 @@ void import_threads_cancel()
 #endif
   cc1=pthread_join(vthread, &status);
   
-  if(verbose & TC_DEBUG) fprintf(stderr, "(%s) video thread exit (ret_code=%d) (status_code=%d)\n", __FILE__, cc1, (int) status);
+  if(verbose & TC_DEBUG) fprintf(stderr, "(%s) video thread exit (ret_code=%d) (status_code=%lu)\n", __FILE__, cc1, (unsigned long)status);
   
 #ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
   pthread_cond_signal(&aframe_list_full_cv);
@@ -147,7 +144,7 @@ void import_threads_cancel()
 #endif
   cc2=pthread_join(athread, &status);
   
-  if(verbose & TC_DEBUG) fprintf(stderr, "(%s) audio thread exit (ret_code=%d) (status_code=%d)\n", __FILE__, cc2, (int) status);
+  if(verbose & TC_DEBUG) fprintf(stderr, "(%s) audio thread exit (ret_code=%d) (status_code=%lu)\n", __FILE__, cc2, (unsigned long) status);
 
   cc1 = pthread_mutex_trylock(&vframe_list_lock);
   
