@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video processing tool
+ *  This file is part of transcode, a video processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,10 +27,10 @@
 void *load_module(char *mod, int mode);
 void unload_module(void *handle);
 
-int (*TCV_export)(int opt, void *para1, void *para2);
-int (*TCA_export)(int opt, void *para1, void *para2);
-int (*TCV_import)(int opt, void *para1, void *para2);
-int (*TCA_import)(int opt, void *para1, void *para2);
+// extern int (*TCV_export)(int opt, void *para1, void *para2);
+// extern int (*TCA_export)(int opt, void *para1, void *para2);
+// extern int (*TCV_import)(int opt, void *para1, void *para2);
+// extern int (*TCA_import)(int opt, void *para1, void *para2);
 
 int tcv_export(int opt, void *para1, void *para2);
 int tca_export(int opt, void *para1, void *para2);
