@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,6 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "transcode.h"
 #include "framebuffer.h"
 #include <string.h>
@@ -60,6 +56,8 @@ static char module[TC_BUF_MAX];
 
 filter_t filter[MAX_FILTER];
 
+extern int errno;
+
 int filter_next_free_id(void)
 {
   int n;
@@ -164,7 +162,7 @@ int load_plugin(char *path) {
       c++;
   }
       
-  sprintf(module, "%s/filter_%s.so", path, filter[id].name);
+  snprintf(module, sizeof(module), "%s/filter_%s.so", path, filter[id].name);
   //fprintf(stderr, "[%s] next free ID (%d) is (%d)\n", __FILE__, filter_next_free_id(), id);
   
   // try transcode's module directory
@@ -347,12 +345,15 @@ int load_single_plugin (char *mfilter_string)
 {
   int id = filter_next_free_id()+1;
   vob_t *vob = tc_get_vob();
+  long sret;
 
   fprintf(stderr, "[%s] Loading (%s) ..\n", __FILE__, mfilter_string);
 
   filter[id].namelen = strlen(mfilter_string);
   filter[id].name    = (char *) malloc (filter[id].namelen+1);
-  strcpy(filter[id].name, mfilter_string);
+  sret = strlcpy(filter[id].name, mfilter_string, MAX_FILTER_NAME_LEN);
+  if (tc_test_string(__FILE__, __LINE__, MAX_FILTER_NAME_LEN, sret, errno))
+    return(1);
 
   if (load_plugin(vob->mod_path)==0)  {
     plugins++;
@@ -415,6 +416,10 @@ int plugin_disable_id (int id)
   return 0;
 }
 
+/* the plugin_list_{disabled,enabled,loaded} functions are only
+ * called from socket.c.  there, buf has been memset M_BUF_IZE bytes.
+ * that's where the M_BUF_SIZE comes from in the snprintfs here.
+ */
 int plugin_list_disabled(char *buf)
 {
     int n, pos=0;
@@ -422,13 +427,13 @@ int plugin_list_disabled(char *buf)
     for (n=0; n<MAX_FILTER; n++) {
 	if ( (filter[n].status == 0) && filter[n].name && strlen(filter[n].name)) {
 	    if (pos == 0) { // first
-		pos = sprintf(buf, "\"%s\"", filter[n].name);
+		pos = snprintf(buf, M_BUF_SIZE, "\"%s\"", filter[n].name);
 	    } else {
-		pos += sprintf(buf+pos, ", \"%s\"", filter[n].name);
+		pos += snprintf(buf+pos, M_BUF_SIZE - pos, ", \"%s\"", filter[n].name);
 	    }
 	}
     }
-    sprintf(buf+pos, "\n");
+    snprintf(buf+pos, M_BUF_SIZE - pos, "\n");
     return 0;
 }
 
@@ -439,13 +444,13 @@ int plugin_list_enabled(char *buf)
     for (n=0; n<MAX_FILTER; n++) {
 	if ( (filter[n].status == 1) && filter[n].name && strlen(filter[n].name)) {
 	    if (pos == 0) { // first
-		pos = sprintf(buf, "\"%s\"", filter[n].name);
+		pos = snprintf(buf, M_BUF_SIZE, "\"%s\"", filter[n].name);
 	    } else {
-		pos += sprintf(buf+pos, ", \"%s\"", filter[n].name);
+		pos += snprintf(buf+pos, M_BUF_SIZE - pos, ", \"%s\"", filter[n].name);
 	    }
 	}
     }
-    sprintf(buf+pos, "\n");
+    snprintf(buf+pos, M_BUF_SIZE - pos, "\n");
     return 0;
 }
 
@@ -456,13 +461,13 @@ int plugin_list_loaded(char *buf)
     for (n=0; n<MAX_FILTER; n++) {
 	if (filter[n].name && strlen(filter[n].name)) {
 	    if (pos == 0) { // first
-		pos = sprintf(buf, "\"%s\"", filter[n].name);
+		pos = snprintf(buf, M_BUF_SIZE, "\"%s\"", filter[n].name);
 	    } else {
-		pos += sprintf(buf+pos, ", \"%s\"", filter[n].name);
+		pos += snprintf(buf+pos, M_BUF_SIZE - pos, ", \"%s\"", filter[n].name);
 	    }
 	}
     }
-    sprintf(buf+pos, "\n");
+    snprintf(buf+pos, M_BUF_SIZE - pos, "\n");
     return 0;
 }
 
