@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,17 @@
  *
  */
 
-#include "framebuffer.h"
-
 #ifndef _FILTER_H
 #define _FILTER_H 
 
+#include "framebuffer.h"
+
 #define MAX_FILTER 16
 
+#define M_BUF_SIZE 8192
+
+#define MAX_FILTER_NAME_LEN 32
+
 typedef struct filter_s {
   
   int id;
