@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,15 @@
  *
  */
 
-#include "config.h"
-#include <pthread.h>
-
 #ifndef _FRAMEBUFFER_H
 #define _FRAMEBUFFER_H 
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <pthread.h>
+
 #define FRAME_NULL  -1
 #define FRAME_EMPTY  0
 #define FRAME_READY  1
