@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,33 +28,55 @@
 #include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <pthread.h>
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
-#include <unistd.h>
-#include <fcntl.h>
+#endif
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
+#include <pthread.h>
 #include <signal.h>
-#include <string.h>
 #include <stdarg.h>
+#include <stdio.h>
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#ifdef NET_STREAM
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netdb.h>
+#endif
+
 #include "avilib/avilib.h"
 #include "aclib/ac.h"
 #include "libioaux/framecode.h"
 
-#ifdef NET_STREAM
-#include <netinet/in.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netdb.h>
-#endif
 
 #ifdef __bsdi__
 typedef unsigned int uint32_t;
 #endif
 
 #include "tc_defaults.h"
-#include "tc_functions.h"
+#include "libtc/libtc.h"
 
 // Uglyness from libavcodec - common.h
 // Don't use these except when your code won't work without it, 
@@ -91,9 +113,12 @@ typedef enum {
   SVCD,
   SVCD_PAL,
   SVCD_NTSC,
+  XVCD,
+  XVCD_PAL,
+  XVCD_NTSC,
   DVD,
   DVD_PAL,
-  DVD_NTSC,
+  DVD_NTSC
 } mpeg_profile_t;
 
 
@@ -546,7 +571,7 @@ typedef struct subtitle_header_s {
 void tc_progress(char *string);
 void tc_import_stop_nolock(void);
 void tc_export_stop_nolock(void);
-/* these function are in tc_functions.{ch}
+/* these function are in libtc
 void tc_error(char *fmt, ...);
 void tc_info(char *fmt, ...);
 void tc_warn(char *fmt, ...);
