@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -476,9 +476,10 @@ void rgb_swap(char *image, int pixels)
   rgb_swap_core = rgb_swap_C;
 
 #ifdef ARCH_X86
-#ifdef HAVE_ASM_NASM
   if(tc_accel>0) rgb_swap_core = ac_swap_rgb2bgr_asm;
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel>0) rgb_swap_core = ac_swap_rgb2bgr_asm64;
 #endif
 
   rgb_swap_core(image, pixels);
@@ -807,13 +808,12 @@ void rgb_deinterlace_linear(char *image, int width, int height)
   rgb_average =  rgb_average_C;
   
 #ifdef ARCH_X86 
-#ifdef HAVE_ASM_NASM
-  
   if(tc_accel & MM_MMX)  rgb_average = ac_average_mmx;
   if(tc_accel & MM_SSE)  rgb_average = ac_average_sse;
   if(tc_accel & MM_SSE2) rgb_average = ac_average_sse2;
-  
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2) rgb_average = ac_average_sse2;
 #endif
 
   rgb_deinterlace_core(image, width, height);
@@ -830,24 +830,24 @@ void rgb_deinterlace_linear_blend(char *image, char *tmp, int width, int height)
   // memcpy_accel = memcpy_C; // EMS
   
 #ifdef ARCH_X86 
-#ifdef HAVE_ASM_NASM
-
   if(tc_accel & MM_MMX) {
     rgb_average = ac_average_mmx;  
     // memcpy_accel = ac_memcpy_mmx; // EMS
   }
-
   if(tc_accel & MM_SSE) {
     rgb_average = ac_average_sse;
     // memcpy_accel = ac_memcpy_sse; // EMS
   }
-
   if(tc_accel & MM_SSE2) {
     rgb_average = ac_average_sse2;
     // memcpy_accel = ac_memcpy_sse2; // EMS
   }
-
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2) {
+    rgb_average = ac_average_sse2;
+    // memcpy_accel = ac_memcpy_sse2; // EMS
+  }
 #endif
   
   //process only Y component
