@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
  *
  */
 
+#include "transcode.h"
 #include "framebuffer.h"
 #include "video_trans.h"
 #include "aclib/ac.h"
@@ -42,7 +43,8 @@ int hori_table_8_flag=0;
 int hori_table_8_up_flag=0;
 
 unsigned char gamma_table[256];
-static int gamma_table_flag = 0;
+/* can't be static */
+int gamma_table_flag = 0;
 
 static unsigned long *aa_table;
 static int aa_table_flag = 0;
@@ -59,6 +61,19 @@ static int yuv_vert_resize_init_flag=0;
 static int rgb_vert_resize_init_flag=0;
 static int yuv422_vert_resize_init_flag=0;
 
+int (*yuv_merge_8)(char *row1, char *row2, char *out, int bytes, 
+		   unsigned long weight1, unsigned long weight2);
+
+int (*yuv_merge_16)(char *row1, char *row2, char *out, int bytes, 
+		    unsigned long weight1, unsigned long weight2);
+
+int (*rgb_merge)(char *row1, char *row2, char *out, int bytes, 
+		 unsigned long weight1, unsigned long weight2);
+
+int (*yuv422_merge)(char *row1, char *row2, char *out, int bytes, 
+		 unsigned long weight1, unsigned long weight2);
+
+
 void yuv_vert_resize_init(int width)
 {
   
@@ -68,7 +83,6 @@ void yuv_vert_resize_init(int width)
   yuv_merge_16 = yuv_merge_C;
 
 #ifdef ARCH_X86
-#ifdef HAVE_ASM_NASM
   
   if(((width>>1) % 16) == 0) {
     if(tc_accel & MM_MMXEXT) yuv_merge_8 = ac_rescale_mmxext;
@@ -91,6 +105,14 @@ void yuv_vert_resize_init(int width)
   }
   
 #endif
+
+#ifdef ARCH_X86_64
+  if(((width>>1) % 16) == 0) {
+    if(tc_accel & MM_SSE2) yuv_merge_8 = ac_rescale_sse2; 
+  }
+  if((width % 16) == 0) {
+    if(tc_accel & MM_SSE2) yuv_merge_16=ac_rescale_sse2; 
+  }
 #endif
   
   return;
@@ -104,24 +126,24 @@ void yuv422_vert_resize_init()
   
 #if 0
 #ifdef ARCH_X86
-#ifdef HAVE_ASM_NASM
-  
   if(tc_accel & MM_SSE2) {
     yuv422_merge=ac_rescale_sse2;
     return;
   }
-  
   if(tc_accel & MM_SSE) {
     yuv422_merge=ac_rescale_sse;
     return;
   }
-  
   if(tc_accel & MM_MMXEXT) {
     yuv422_merge=ac_rescale_mmxext;
     return;
   }
-  
 #endif
+#if ARCH_X86_64
+  if(tc_accel & MM_SSE2) {
+    yuv422_merge=ac_rescale_sse2;
+    return;
+  }
 #endif
 #endif // 0
   
@@ -136,24 +158,24 @@ void rgb_vert_resize_init()
   rgb_vert_resize_init_flag=1;
   
 #ifdef ARCH_X86
-#ifdef HAVE_ASM_NASM
-  
   if(tc_accel & MM_SSE2) {
     rgb_merge=ac_rescale_sse2;
     return;
   }
-  
   if(tc_accel & MM_SSE) {
     rgb_merge=ac_rescale_sse;
     return;
   }
-  
   if(tc_accel & MM_MMXEXT) {
     rgb_merge=ac_rescale_mmxext;
     return;
   }
-  
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2) {
+    rgb_merge=ac_rescale_sse2;
+    return;
+  }
 #endif
   
   rgb_merge=rgb_merge_C;
@@ -163,7 +185,7 @@ void rgb_vert_resize_init()
 
 inline void clear_mmx()
 {
-#ifdef ARCH_X86
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
 #ifdef HAVE_MMX
   __asm __volatile ("emms;":::"memory");    
 #endif
@@ -425,18 +447,15 @@ int process_yuv422_frame(vob_t *vob, vframe_list_t *ptr)
 
     if(!yuv422_vert_resize_init_flag) yuv422_vert_resize_init(ptr->v_width);
     
-     if(tmp_image == NULL) {
-      if((tmp_image = (char *)calloc(1, SIZE_RGB_FRAME))==NULL) {
-	fprintf(stderr, "(%s) out of memory", __FILE__);
-	exit(1);
-      }
-    }
     if(!vert_table_8_up_flag) {
       init_table_8_up(vert_table_8_up, ptr->v_height, vob->vert_resize2);
       vert_table_8_up_flag=1;
     }
     
-    yuv422_vresize_8_up(ptr->video_buf, ptr->v_width, ptr->v_height, vob->vert_resize2);
+    yuv422_vresize_8_up(ptr->video_buf, ptr->video_buf_Y[ptr->free], ptr->v_width, ptr->v_height, vob->vert_resize2);
+
+    ptr->video_buf = ptr->video_buf_Y[ptr->free];
+    ptr->free = (ptr->free) ? 0:1;
     
     ptr->v_height += vob->vert_resize2<<3;    
     ptr->video_size = ptr->v_height *  ptr->v_width * ptr->v_bpp/8/2 *3;
@@ -453,18 +472,15 @@ int process_yuv422_frame(vob_t *vob, vframe_list_t *ptr)
 
   if(resize2 && vob->hori_resize2) {
 
-     if(tmp_image == NULL) {
-      if((tmp_image = (char *)calloc(1, SIZE_RGB_FRAME))==NULL) {
-	fprintf(stderr, "(%s) out of memory", __FILE__);
-	exit(1);
-      }
-    }
     if(!hori_table_8_up_flag) {
       init_table_8_up(hori_table_8_up, ptr->v_width, vob->hori_resize2);
       hori_table_8_up_flag=1;
     }
     
-    yuv422_hresize_8_up(ptr->video_buf, ptr->v_width, ptr->v_height, vob->hori_resize2);
+    yuv422_hresize_8_up(ptr->video_buf, ptr->video_buf_Y[ptr->free], ptr->v_width, ptr->v_height, vob->hori_resize2);
+
+    ptr->video_buf = ptr->video_buf_Y[ptr->free];
+    ptr->free = !ptr->free;
 
     ptr->v_width += vob->hori_resize2<<3;    
     ptr->video_size = ptr->v_height *  ptr->v_width * ptr->v_bpp/8/2 *3;
@@ -1091,7 +1107,7 @@ int process_yuv_frame(vob_t *vob, vframe_list_t *ptr)
     if(!aa_table_flag) init_aa_table(vob->aa_weight, vob->aa_bias);
     
     //UV components unchanged
-    memcpy(ptr->video_buf_Y[ptr->free]+ptr->v_width*ptr->v_height, ptr->video_buf + ptr->v_width*ptr->v_height, ptr->v_width*ptr->v_height/2);
+    tc_memcpy(ptr->video_buf_Y[ptr->free]+ptr->v_width*ptr->v_height, ptr->video_buf + ptr->v_width*ptr->v_height, ptr->v_width*ptr->v_height/2);
     
     yuv_antialias(ptr->video_buf, ptr->video_buf_Y[ptr->free], ptr->v_width, ptr->v_height, vob->antialias);
     
@@ -1222,20 +1238,16 @@ int process_rgb_frame(vob_t *vob, vframe_list_t *ptr)
      
      if(!rgb_vert_resize_init_flag) rgb_vert_resize_init();
      
-     if(tmp_image == NULL) {
-       
-      if((tmp_image = (char *)calloc(1, SIZE_RGB_FRAME))==NULL) {
-	fprintf(stderr, "(%s) out of memory", __FILE__);
-	exit(1);
-      }
-    }
-    
     if(!vert_table_8_up_flag) {
       init_table_8_up(vert_table_8_up, ptr->v_height, vob->vert_resize2);
       vert_table_8_up_flag=1;
     }
     
-    rgb_vresize_8_up(ptr->video_buf, ptr->v_width, ptr->v_height, vob->vert_resize2);
+    rgb_vresize_8_up(ptr->video_buf, ptr->video_buf_RGB[ptr->free], ptr->v_width, ptr->v_height, vob->vert_resize2);
+
+    // adjust pointer, zoomed frame in tmp buffer
+    ptr->video_buf = ptr->video_buf_RGB[ptr->free];
+    ptr->free = (ptr->free) ? 0:1;
 
     ptr->v_height += vob->vert_resize2<<3;    
     ptr->video_size = ptr->v_height *  ptr->v_width * ptr->v_bpp/8;
@@ -1251,20 +1263,15 @@ int process_rgb_frame(vob_t *vob, vframe_list_t *ptr)
 
   if(resize2 && vob->hori_resize2) {
 
-    if(tmp_image == NULL) {
-      
-      if((tmp_image = (char *)calloc(1, SIZE_RGB_FRAME))==NULL) {
-	fprintf(stderr, "(%s) out of memory", __FILE__);
-	exit(1);
-      }
-    }
-    
     if(!hori_table_8_up_flag) {
       init_table_8_up(hori_table_8_up, ptr->v_width, vob->hori_resize2);
       hori_table_8_up_flag=1;
     }
     
-    rgb_hresize_8_up(ptr->video_buf, ptr->v_width, ptr->v_height, vob->hori_resize2);
+    rgb_hresize_8_up(ptr->video_buf, ptr->video_buf_RGB[ptr->free], ptr->v_width, ptr->v_height, vob->hori_resize2);
+
+    ptr->video_buf = ptr->video_buf_RGB[ptr->free];
+    ptr->free = (ptr->free) ? 0:1;
 
     ptr->v_width += vob->hori_resize2<<3;    
     ptr->video_size = ptr->v_height *  ptr->v_width * ptr->v_bpp/8;
