@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1495,13 +1495,12 @@ void yuv_deinterlace_linear(char *image, int width, int height)
   yuv_average =  yuv_average_C;
   
 #ifdef ARCH_X86 
-#ifdef HAVE_ASM_NASM
-
   if(tc_accel & MM_MMX)  yuv_average = ac_average_mmx;  
-  if(tc_accel & MM_SSE)  yuv_average = ac_average_sse;
-  if(tc_accel & MM_SSE2) yuv_average = ac_average_sse2;
-  
+  if(tc_accel & MM_SSE && (width % 8 == 0))  yuv_average = ac_average_sse;
+  if(tc_accel & MM_SSE2 && (width % 16 == 0)) yuv_average = ac_average_sse2;
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2 && (width % 16 == 0)) yuv_average = ac_average_sse2;
 #endif
   
   //process only Y component
@@ -1519,25 +1518,26 @@ void yuv_deinterlace_linear_blend(char *image, char *tmp, int width, int height)
 //   memcpy_accel = memcpy_C; // EMS
   
 #ifdef ARCH_X86 
-#ifdef HAVE_ASM_NASM
-
   if(tc_accel & MM_MMX) {
     yuv_average = ac_average_mmx;  
     // memcpy_accel = ac_memcpy_mmx; // EMS
   }
-
-  if(tc_accel & MM_SSE) {
+  // Note that we need width/2 to be properly aligned since we're going
+  // to be doing the half-resolution chroma planes too
+  if(tc_accel & MM_SSE && (width % 16 == 0)) {  
     yuv_average = ac_average_sse;
     // memcpy_accel = ac_memcpy_sse; // EMS
   }
-
-  if(tc_accel & MM_SSE2) {
+  if(tc_accel & MM_SSE2 && (width % 32 == 0)) {
     yuv_average = ac_average_sse2;
     // memcpy_accel = ac_memcpy_sse2; // EMS
   }
-
-  
 #endif
+#ifdef ARCH_X86_64
+  if(tc_accel & MM_SSE2 && (width % 32 == 0)) {
+    yuv_average = ac_average_sse2;
+    // memcpy_accel = ac_memcpy_sse2; // EMS
+  }
 #endif
   
   //process only Y component
