@@ -5,7 +5,7 @@
  *
  *  Copyright (C) Tilmann Bitterberg - June 2003
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -638,7 +638,7 @@ int main(int argc, char *argv[])
 		print_ms = aud_ms[audtr];
 		chunk = avifile1->track[audtr].audio_posc;
 		break;
-	case 10: sprintf(tag, "idx1");
+	case 10: snprintf(tag, sizeof(tag), "idx1");
 		 index_pos = pos;
 		 index_len = len;
 		 print_ms = 0.0;
