@@ -3,7 +3,7 @@
  *
  *  Copyright (C) Thomas streich - June 2001
  *
- *  This file is part of transcode, a linux video stream processing tool
+ *  This file is part of transcode, a video stream processing tool
  *      
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -750,7 +750,7 @@ int main(int argc, char *argv[])
   AVI_close(avifile2);
 
   if (avifile3) {
-      memset(nulls, 0, 1024); sprintf(nulls, "rm -f %s", tmp0); system(nulls);
+      memset(nulls, 0, 1024); snprintf(nulls, sizeof(nulls), "rm -f %s", tmp0); system(nulls);
       AVI_close(avifile3);
   }
   
